<?php

/* what is needed to create the admin page */
add_action( 'after_setup_theme', 'clf_base_after_setup_theme',15 );
add_action('init','clf_base_init',1);
add_action('admin_menu', 'clf_base_admin_menu');
add_action('admin_init', 'clf_base_admin_init', 11);
add_action('save_post','clf_base_generate_styles_from_custom_css', 10, 2); 

// ajax functions
add_action('wp_ajax_clf_base_theme_options', 'clf_base_theme_options_ajax');
add_action('wp_ajax_clf_base_theme_import', 'clf_base_theme_options_ajax_import');
add_action('wp_ajax_clf-base-theme-export', 'clf_base_theme_options_ajax_export');
add_action('wp_ajax_nopriv_clf-base-theme-export','clf_base_theme_options_ajax_export');

add_action('switch_theme', 'clf_base_unstall_theme');
add_filter('style_loader_src','clf_base_fonts_and_colours_style_url');
add_filter('clf_base_theme_options_validate','clf_base_generate_styles',1);
add_filter('clf_base_theme_options_validate','clf_base_generate_editor_styles');
add_filter('clf_base_theme_options_validate','clf_base_update_section_widget_settings_update');

add_filter('mce_css', 'clf_base_mcekit_editor_style');

add_action('hybrid_head', 'clf_base_add_print_stylesheet');

add_action( 'wp_before_admin_bar_render', 'clf_base_admin_bar_render' );

/* what is needed to create the admin page */
require('includes/color-mixer.php');



// in this part we load the required things this keeps our functions file lean 
/**
 * clf_base_after_setup_theme function.
 * 
 * @access public
 * @return void
 */
function clf_base_after_setup_theme(){
	global $clf_base_load_backend, $clf_base_options, $clf_base_version;
	/** 
 	* Load the theme options that you would like to see on the theme options page 
 	* The order of the files inclided deteremins the order in which they appear in the theme options menu
 	*/
	require_if_theme_supports( 'clf', 	 CHILD_THEME_DIR. '/library/clf-header/init.php' );
	require_if_theme_supports( 'clf', 	 CHILD_THEME_DIR. '/library/clf/init.php' );
	require_if_theme_supports( 'clf-layout', CHILD_THEME_DIR. '/library/layout/init.php' );
	require_if_theme_supports( 'clf-fonts-and-colors', CHILD_THEME_DIR. '/library/fonts-and-colors/init.php' );
	require_if_theme_supports( 'clf-navigation', CHILD_THEME_DIR. '/library/navigation/init.php' );
	require_if_theme_supports( 'clf-display-options', CHILD_THEME_DIR. '/library/display-options/init.php' );
	require_if_theme_supports( 'clf-images', CHILD_THEME_DIR. '/library/images/init.php' );
	require_if_theme_supports( 'clf-scripts', CHILD_THEME_DIR. '/library/scripts/init.php' );
	require_if_theme_supports( 'clf-frontpage', CHILD_THEME_DIR. '/library/frontpage/init.php' );
	require_if_theme_supports( 'clf-custom-fields', CHILD_THEME_DIR. '/library/custom-fields/init.php' );
	require_if_theme_supports( 'clf-mobile', CHILD_THEME_DIR. '/library/mobile/init.php' );
	require_if_theme_supports( 'clf-SEO', CHILD_THEME_DIR. '/library/SEO/init.php' );
	require_if_theme_supports( 'clf-shortcodes', CHILD_THEME_DIR. '/library/shortcodes/init.php' );
	
}

/**
 * clf_base_init function.
 * 
 * removes unwanted actions 
 * @access public
 * @return void
 */
function clf_base_init()
{
	global $clf_base_options,$clf_base_version;
	/* remove Default Hybrid Theme Options */
	remove_action( 'hybrid_footer', 'hybrid_footer_insert' );
	remove_action( 'admin_menu', 'hybrid_create_meta_box');
    remove_action( 'save_post', 'hybrid_save_meta_data' );
    remove_action( 'init', 'hybrid_admin_init' );
    
    // removes security issue 
	remove_action('hybrid_head', 'wp_generator'); 
	remove_action('hybrid_head','hybrid_meta_template');
	remove_action('wp_head', 'wlwmanifest_link');
	remove_action('wp_head', 'rsd_link');
	
	
    // remove section widget Options 
    remove_action('admin_menu', 'tabbed_section_widget_add_option_page');
    
	add_filter('clf_base_add_style_path', 'clf_base_default_style_css_path',1);
	add_filter('clf_base_add_editor_style_path', 'clf_base_default_style_css_path',1);
	
	add_filter('clf_base_add_editor_style_path', 'clf_base_default_style_css_path',1);
	
	add_filter('clf_base_modify_style_css_content', 'clf_base_add_style_css_content_filter');
	add_filter('stylesheet_uri','clf_base_stylesheet_uri_filter');
	
	//add_filter('script_loader_src', 'clf_base_script_uri_filter');
	//add_filter('style_loader_src', 'clf_base_script_uri_filter');

	if( !(current_user_can( 'manage_options' )) || !is_admin_bar_showing() || is_admin() ):
		// better simpler-css intergration 
	    
	    remove_action( 'wp_head', 'simpler_css_addcss');
	    add_filter('clf_base_add_style_css_content','clf_base_add_simpler_css',100);
	    
	    
	    // better improved-simpler-css intergration
	    remove_action( 'wp_head', 'improved_simpler_css_addcss');
    	remove_action( 'wp_enqueue_scripts', array('Improved_Simpler_CSS','load_style') );
    endif;
	
	if($clf_base_options['version'] < $clf_base_version || empty($clf_base_options['version']) )
	{
		$clf_base_options['version'] = $clf_base_version;
		$clf_base_options = clf_base_theme_options_validate($clf_base_options);
		update_option( 'clf_base',$clf_base_options );
		
	}
}
/**
 * clf_base_default_style_css_path function.
 * 
 * @access public
 * @param mixed $paths
 * @return void
 */
function clf_base_default_style_css_path($paths) {
	global $clf_base_options;
	$paths[] = "/editor.css"; // used to reset styles only now
	
	
	if(isset($clf_base_options['fonts-and-colors']['typography']['style']))
		$paths[] = "/library/fonts-and-colors/typography/".$clf_base_options['fonts-and-colors']['typography']['style'].".css";
	else
		$paths[] = "/library/fonts-and-colors/typography/default.css";
	$paths[] = "/style.css";
	return $paths;
}


/**
 * clf_base_editor_style_css_path function.
 * 
 * @access public
 * @param mixed $paths
 * @return void
 */
function clf_base_editor_style_css_path($paths) {
	global $clf_base_options;
	$paths[] = "/editor.css"; 
	
	
	if(isset($clf_base_options['fonts-and-colors']['typography']['style']))
		$paths[] = "/library/fonts-and-colors/typography/".$clf_base_options['fonts-and-colors']['typography']['style'].".css";
	else
		$paths[] = "/library/fonts-and-colors/typography/default.css";
	//$paths[] = "/editor.css";
	return $paths;
}

/**
 * clf_base_stylesheet_uri_filter function.
 * 
 * @access public
 * @param mixed $path
 * @return void
 */
function clf_base_stylesheet_uri_filter($path){
	global $clf_base_options;
	$wp_site_upload_directory = wp_upload_dir();
	if( !(current_user_can( 'manage_options' )) || !is_admin_bar_showing() || is_admin() )
		return $wp_site_upload_directory ['baseurl'].'/clf_base/css/'.$clf_base_options['style']['mini'];
	else
		return $wp_site_upload_directory ['baseurl'].'/clf_base/css/'.str_replace('clf-base-dev.css','clf-base-admin.css',$clf_base_options['style']['dev']);
		
}



/**
 * clf_base_admin_menu function.
 * Created the Options Page under the Apperances menu 
 * @access public
 * @return void
 */
function clf_base_admin_menu() { 
	// Action to add admin menu page.
	$clf_base_theme_options = add_theme_page(
	   'Theme Options', // <title> Page title
	   'Theme Options', // <h1> Page title
	   'administrator', // User role
	   'clf-base-theme-options', // Admin Options identifier/handle
	   'clf_base_theme_options_form'); // Function to display the page 
	 
	 add_action('admin_print_styles-' . $clf_base_theme_options, 'clf_base_init_admin_styles');
	 
}


function clf_base_admin_bar_render() {
	global $wp_admin_bar;
	// we can remove a menu item, like the COMMENTS link
    // just by knowing the right $id
	
	// we can add a submenu item too
	$wp_admin_bar->add_menu( array(
        'parent' => 'appearance',
        'id' => 'clf_theme',
        'title' => __('Theme Options'),
        'href' => admin_url( 'themes.php?page=clf-base-theme-options')
    ) );
}


/**
 * clf_base_admin_init function.
 * 
 * @access public
 * @return void
 */
function clf_base_admin_init() { 
	// Action to register sections and settings to new menu page.
	global $page,$pagenow, $clf_base_options,$clf_base_version;
	
    // removes the hybrid theme settings page 
	remove_action('admin_menu', 'hybrid_settings_page_init' );
	// register settings
	register_setting( 'clf_base_theme_options', 'clf_base', 'clf_base_theme_options_validate');
	
	// make this only happen on the particular page not everywhere in the admin
	
	wp_register_style('clf-base-css-ui', get_bloginfo('stylesheet_directory').'/library/admin/theme-options.css');
	// color picker
	wp_register_style('clf-base-color-picker', get_bloginfo('stylesheet_directory').'/library/admin/includes/colorpicker/css/colorpicker.css');
	
	add_settings_section('export', 'Export', 'clf_base_theme_options_export', 'clf-base-theme-options' ); 
	add_settings_section('import', 'Import', 'clf_base_theme_options_import', 'clf-base-theme-options' );
	
	add_settings_field('clf-base-export', 'Export', 'clf_base_theme_options_export_fields', 'clf-base-theme-options', 'export');
	add_settings_field('clf-base-import', 'Import', 'clf_base_theme_options_import_fields', 'clf-base-theme-options', 'import');
	
	
	add_action("clf-base-theme-options-hidden", "clf_base_theme_options_version");
	/* 
	 * Run this code when the theme is first initialized 
	 */
	if ( isset($_GET['activated'] ) && $pagenow == 'themes.php' ) :
		
		// sets the default settings in our theme 
		$default_import = json_decode( file_get_contents(WP_CONTENT_DIR.'/themes/clf-base/library/admin/default-import.json'),TRUE );

		
		if( is_array($default_import) ):
			$clf_base_options = $default_import ;
			$worked = update_option("clf_base", $default_import);
		endif;
		
		clf_base_update_section_widget_settings();
	endif;
	
	
}

function clf_base_theme_options_version()
{
	global $clf_base_options;
	echo "<input type='hidden' name='clf_base[version]' value=\"".esc_attr($clf_base_options['version'])."\" />";
}
/**
 * clf_base_update_section_widget_settings function.
 * 
 * @access public
 * @return void
 */
function clf_base_update_section_widget_settings()
{
	// make sure that the section widget is installed properly
	$section_options = array(
	"theme" =>  "none",
	"scope" => ".swt-outter",
	"heightfix" =>  false
	);
	update_option( 'section-widget-settings', $section_options );
}
/**
 * clf_base_update_section_widget_settings_update function.
 * 
 * @access public
 * @param mixed $input
 * @return void
 */
function clf_base_update_section_widget_settings_update($input)
{
	$section_options = get_option( 'section-widget-settings');
	
	if($section_options['theme'] != "none" )
		clf_base_update_section_widget_settings();

	return $input;

}
/**
 * clf_base_generate_styles_from_custom_css function.
 * 
 * @access public
 * @return void
 */
function clf_base_generate_styles_from_custom_css($post_id,$post)
{	
	
	if($post->post_type == "s-custom-css"):
		global $clf_base_options;
		/* Better simpler css intergration custom css plugin */
		update_option("clf_base", $clf_base_options); // clf_base_generate_styles( $clf_base_options );
	endif;

}
/**
 * clf_base_init_admin_styles function.
 * 
 * @access public
 * @return void
 */
function clf_base_init_admin_styles() {
	
	wp_enqueue_style( 'clf-base-css-ui'); // main style sheet
	wp_enqueue_style( 'clf-base-color-picker');
	
	// color picker
	wp_enqueue_script('clf-base-js-color-picker', get_bloginfo('stylesheet_directory').'/library/admin/includes/colorpicker/js/colorpicker.js', array('clf-base-js-ui'));
	
	// main js file 
	wp_enqueue_script('clf-base-js-ui', get_bloginfo('stylesheet_directory').'/library/admin/theme-options.js', array('jquery','jquery-ui-tabs'));
	// enables us to only set the stylesheets and js on these pages
	do_action("clf_base_admin_ui");
}


/**
 * clf_base_theme_options_form function.
 * 
 * @access public
 * @return void
 */
function clf_base_theme_options_form() {
	global $clf_base_options;
		
?>
<div class="wrap">
	<div id="icon-themes" class="icon32"><br /></div>
	<h2>Theme Options</h2>
	<form method="post" action="themes.php?page=clf-base-theme-options" id="clf-base-form">
	<div class="submit">
		<div id="clf-base-ajax-report" class="updated fade below-h2"></div>
		<input type="submit" class="button-primary" value="<?php _e('Save Changes') ?>" />
		<img src="images/wpspin_light.gif" id="clf-base-ajax-feedback" title="" alt="" />
		<span class="save-changes">There are some unsaved changes</span>
		</div>
	<?php settings_fields('clf_base_theme_options'); ?>
		
	<div id="clf-base-theme-options-shell" >
		<?php clf_base_tabs_do_settings_sections("clf-base-theme-options"); ?>
	</div>
	<div class="submit">
		<input type="submit" id="bottom-submit" class="button-primary" value="<?php _e('Save Changes') ?>" />
		<img src="images/wpspin_light.gif" id="clf-base-ajax-feedback" title="" alt="" />
		<span class="save-changes">There are some unsaved changes</span>
		</div>
	<?php do_action("clf-base-theme-options-hidden"); ?>
	</form>
</div>

<?php	
}

/**
 * clf_base_theme_options_validate function.
 * 
 * @access public
 * @param mixed $input
 * @return void
 */
function clf_base_theme_options_validate($input) {

	return apply_filters( 'clf_base_theme_options_validate', $input );
	
	
}

/**
 * clf_base_theme_options_export function.
 * 
 * @access public
 * @return void
 */
function clf_base_theme_options_export() {
	echo '<p></p>';
}

/**
 * clf_base_theme_options_export_fields function.
 * 
 * @access public
 * @return void
 */
function clf_base_theme_options_export_fields()
{
	global $clf_base_options;
	?>
	<p>export url <input size="79" type="text" value="<?php echo admin_url('admin-ajax.php'); ?>?action=clf-base-theme-export" /> </p>
	
	<?php
}

/**
 * clf_base_theme_options_import function.
 * 
 * @access public
 * @return void
 */
function clf_base_theme_options_import() {
	echo '<p></p>';
}

/**
 * clf_base_theme_options_import_fields function.
 * 
 * @access public
 * @return void
 */
function clf_base_theme_options_import_fields() {
	global $clf_base_options;
	?>
	
	<p>
	Enter url
	<input size="79" type="text" value="http://" id="import-url"  /> </p>
	<?php 
	/*
	 <!--  or <a href="#import" id="preview-url-action" class="button" >Preview</a></p> -->
	<!-- 
	<ul id="import-theme-settings">
	<?php foreach($clf_base_options as $key=>$value ): ?>
		<li><label><input type="checkbox" name="clf_base_['<?php echo $key;?>']" /> <?php echo $key; ?></label>
		
		<?php 
		if(is_array($value)):
		?>
			<ul>
		<?php 
			foreach($value as $key_level_1 => $value_level_1): ?>
				<li><label><input type="checkbox" name="clf_base_['<?php echo $key;?>']['<?php echo $key_level_1;?>']" /> <?php echo $key_level_1; ?> </label>
				
				<?php 
				if(is_array( $value_level_1 )): ?>
					<ul>
					<?php 
					foreach($value_level_1 as $key_level_2 => $value_level_2): ?>
						<li><label><input type="checkbox" name="clf_base_['<?php echo $key;?>']['<?php echo $key_level_1;?>']['<?php echo $key_level_2;?>']" /> <?php echo $key_level_2; ?></label></li>
					<?php   
					endforeach; ?>
					</ul>
				<?php	
				endif;
			 	?>
			 	
			</li>
		<?php 
			endforeach; ?>
		</ul>
		<?php
		endif; ?>
		</li>
	<?php endforeach; ?>
	</ul>
	*/ ?>
	<p><a href="#import" id="import-url-action" class="button" >Import Settings</a> <span id="import-response"></span>
	<?php
}

/**
 * clf_base_tabs_do_settings_sections function.
 * 
 * @access public
 * @param mixed $page
 * @return void
 */
function clf_base_tabs_do_settings_sections($page) {
	global $wp_settings_sections, $wp_settings_fields;
	
	if ( !isset($wp_settings_sections) || !isset($wp_settings_sections[$page]) )
		return;
	
	echo "<ul class='ui-tabs-nav ui-helper-reset ui-helper-clearfix ui-widget-header ui-corner-all'>";
	foreach ( (array) $wp_settings_sections[$page] as $section ) {
		
		echo "<li><a href='#{$section['id']}'>{$section['title']}</a></li>\n";
	}
	echo "</ul>";
	
	foreach ( (array) $wp_settings_sections[$page] as $section ) {
		
		
		
		echo "<div id='{$section['id']}' class='ui-tabs-panel ui-widget-content ui-corner-bottom'><h3>{$section['title']}</h3>\n";
		call_user_func($section['callback'], $section);
		if ( isset($wp_settings_fields[$page][$section['id']]) ):			
			echo '<div class="form-table-shell"><table class="form-table">';
			do_settings_fields($page, $section['id']);
			echo '</table></div>';
		endif;
		echo '</div>';
		
	}
}

/**
 * clf_base_theme_options_ajax function.
 * 
 * @access public
 * @return void
 */
function clf_base_theme_options_ajax() {
	
	// validate the data
	$option = "clf_base";
	
	
	// where the data needs to be saved to  
	// otherwise
	// save the data
		
	$value = null;
	if ( isset($_POST[$option]) )
	$value = $_POST[$option];
		
	if ( !is_array($value) ) $value = trim($value);
		$value = stripslashes_deep($value);	
	
	if( update_option($option, $value) ):
		echo "success";
	else:
	// if validatetion failes
	// report an error
		echo "fail";
	endif;
	
	die();

}

/**
 * clf_base_theme_options_ajax_import function.
 * 
 * @access public
 * @return void
 */
function clf_base_theme_options_ajax_import()
{
	global $clf_base_options;
	// validate the data
	$option = "clf_base";
	
	$contents = wp_remote_fopen(urldecode($_POST['url']));
	$contents = json_decode($contents,TRUE);
	
	if(is_array($contents)):

		$worked = update_option("clf_base", $contents);
		
		if($worked)
			echo "success";
		else
			echo "Settings Already Saved";
			
	else:
		echo "Please check you import url! ";
		
	endif;
	
	die();

}

/**
 * clf_base_theme_options_ajax_export function.
 * 
 * @access public
 * @return void
 */
function clf_base_theme_options_ajax_export()
{
	global $clf_base_options;
	echo json_encode( $clf_base_options );
	die();
}

/**
 * clf_base_add_style_css_content_filter function.
 * This function is used to be able to 
 * @access public
 * @param mixed $css
 * @return void
 */
function clf_base_add_style_css_content_filter($css)
{
	global $clf_base_options;	
	
	$css .= stripslashes($clf_base_options['global']['clf_base_add_style_css_content_action']['custom-css']);

	return $css;
}

/**
 * clf_base_generate_styles function.
 * create a stylesheet and store it in the uploads folder
 * @access public
 * @return void
 */
function clf_base_generate_styles( $options )
{
	global $clf_base_options;
	
	$clf_base_options = $options;
	$style_paths = array();
	
	$style_paths = apply_filters( 'clf_base_add_style_path', $style_paths);
	
	// go though all the urls and extract all the css out of them
	foreach($style_paths as $file):
		$css_content .= "/* $file */";
		$css_content .= @file_get_contents( STYLESHEETPATH. $file );
	endforeach;
	$admin_css  = $css_content;
	$css_content =  apply_filters( 'clf_base_add_style_css_content', $css_content );
	
	$css_content =  apply_filters( 'clf_base_modify_style_css_content', $css_content );
	
	

	/* we are creating a new admin_css file */
	remove_filter( 'clf_base_add_style_css_content','clf_base_add_simpler_css', 100);
	
	$admin_css =  apply_filters( 'clf_base_add_style_css_content', $admin_css );
	
	$admin_css =  apply_filters( 'clf_base_modify_style_css_content', $admin_css );
	
	// add the filter back for just in case...
	add_filter('clf_base_add_style_css_content','clf_base_add_simpler_css',100);
	
	// minify the css 
	$css_content_minify = clf_base_minify_style( $css_content );
	
	// create the file 
	$wp_site_upload_directory = wp_upload_dir();


	$style_folder_dir = $wp_site_upload_directory['basedir']."/clf_base/css/";	
	 
	if( file_exists( $style_folder_dir ) ):
	// delete the previous css files 
		if ( $style_dir = opendir( $style_folder_dir ) ) {
			
			while ( false !== ( $style_file = readdir($style_dir) ) ):
				if ( (preg_match( "/-mini-/", $style_file ) || preg_match( "/-dev/", $style_file ))  && '.' != $style_file && '..' != $style_file ):	
					@unlink( $style_folder_dir . '/' .  $style_file );
				endif;
				
			endwhile;
		}
		
		closedir( $style_dir );
		/* */
	else:
		if( !file_exists( $wp_site_upload_directory['basedir']."/clf_base/" ) )
			mkdir( $wp_site_upload_directory['basedir']."/clf_base/" );
		
		mkdir( $style_folder_dir ,0777,true);
	endif; 
	
	// create the new files 
	
	// 			
	$minified_file = 'clf-base-mini-'.time().'.css';
	$minified_style_file  = fopen( $style_folder_dir.$minified_file, 'w') or die("can't open file");
	fwrite($minified_style_file,$css_content_minify);
	fclose($minified_style_file);
	
	// write the developer file
	$developer_file = 'clf-base-dev.css';
	$developer_style_file = fopen( $style_folder_dir.$developer_file, 'w') or die("can't open file");
	
	fwrite($developer_style_file,$css_content);
	fclose($developer_style_file);
	
	// write the admin file 
	$admin_file = 'clf-base-admin.css';
	$admin_style_file = fopen( $style_folder_dir.$admin_file, 'w') or die("can't open file");
	
	fwrite($admin_style_file,$admin_css);
	fclose($admin_style_file);
	
	$clf_base_options['style']['mini'] 	= $minified_file;
	$clf_base_options['style']['dev'] 	= $developer_file;
	
	// clear the cache 
	if(function_exists('wp_cache_clear_cache'))
		wp_cache_clear_cache();
	
	return $clf_base_options;
}
/**
 * clf_base_generate_editor_styles function.
 * 
 * @access public
 * @param mixed $options
 * @return void
 */
function clf_base_generate_editor_styles( $options )
{
	global $clf_base_options;
	$clf_base_options = $options;
	$style_paths = array();
	
	$style_paths = apply_filters( 'clf_base_add_editor_style_path', $style_paths);
	
	// go though all the urls and extract all the css out of them
	foreach($style_paths as $file):
		$css_content .= "/* $file */";
		$css_content .= @file_get_contents(STYLESHEETPATH. $file );
	endforeach;
	
	$css_content =  apply_filters( 'clf_base_add_editor_style_css_content', $css_content );
	
	$css_content =  apply_filters( 'clf_base_modify_editor_style_css_content', $css_content );
	
	// minify the css 
	$css_content_minify = clf_base_minify_style( $css_content );
	
	// create the file 
	$wp_site_upload_directory = wp_upload_dir();

	
	$style_folder_dir = $wp_site_upload_directory['basedir']."/clf_base/css/";
	
	
	// delete previous files 
	if( file_exists  (  $style_folder_dir )):
		if ( $style_dir = opendir( $style_folder_dir ) ) {
			while ( false !== ( $style_file = readdir($style_dir) ) ) {
				if ( ( preg_match( "/-editor-/", $style_file ) || preg_match( "/-editor-dev/", $style_file ) ) && '.' != $style_file && '..' != $style_file )
					@unlink( $style_folder_dir . '/' .  $style_file );
			}
		}
		
		closedir( $style_dir );
	else:
		mkdir( $style_folder_dir );
	endif; 
	
	// create the new files 
	// 			
	$minified_file = 'clf-base-editor-'.time().'.css';
	$minified_style_file  = fopen( $style_folder_dir.$minified_file, 'w') or die("can't open file");
	
	
	fwrite($minified_style_file,$css_content_minify);
	fclose($minified_style_file);
	
	$developer_file = 'clf-base-editor-dev.css';
	$developer_style_file = fopen( $style_folder_dir.$developer_file, 'w') or die("can't open file");
	
	fwrite($developer_style_file,$css_content);
	fclose($developer_style_file);
	
	$clf_base_options['style']['editor-mini'] 	= $minified_file;
	$clf_base_options['style']['editor-dev'] 	= $developer_file;

	return $clf_base_options;
}
/**
 * clf_base_minify_style function.
 * minifies the stylesheet
 * @access public
 * @param mixed $v
 * @return void
 */
function clf_base_minify_style($v)
{
		$v = trim($v);
		$v = str_replace("\r\n", "\n", $v);
        $search = array("/\/\*[\d\D]*?\*\/|\t+/", "/\s+/", "/\}\s+/");
        $replace = array(null, " ", "}\n");
		$v = preg_replace($search, $replace, $v);
		$search = array("/\\;\s/", "/\s+\{\\s+/", "/\\:\s+\\#/", "/,\s+/i", "/\\:\s+\\\'/i", "/\\:\s+([0-9]+|[A-F]+)/i");
        $replace = array(";", "{", ":#", ",", ":\'", ":$1");
        $v = preg_replace($search, $replace, $v);
        $v = str_replace("\n", null, $v);
    	return $v;
	
}
/**
 * clf_base_add_simpler_css function.
 * This function adds to the filter 
 * @access public
 * @param mixed $style
 * @return void
 */
function clf_base_add_simpler_css($style)
{
	if(function_exists( 'simpler_css_always_get_css' )):
		return  $style . "
/* Custom CSS */
	".simpler_css_always_get_css().
	"
/* END OF Custom CSS */
	";
	elseif( function_exists('improved_simpler_css_always_get_css') ):
		return  $style . "
/* Custom CSS */
	".improved_simpler_css_always_get_css().
	"
/* END OF Custom CSS */
	";
	elseif( class_exists( 'Improved_Simpler_CSS' ) ):
		return  $style . "
/* Custom CSS */
	". Improved_Simpler_CSS::get_css( false ).
	"
/* END OF Custom CSS */
	";
	
	else:
		
		$simpler_css_css = get_option ( 'simpler_css_css' );
		if(!is_array($simpler_css_css))
			$simpler_css_css = array($simpler_css_css);
			
		return $style . "
	/* Custom CSS */
		".$simpler_css_css[0].
		"
	/* END OF Custom CSS */
		";
	endif;
	
	
	

}
/**
 * clf_base_mcekit_editor_style function.
 * this function add the style sheet for the user
 * @access public
 * @param mixed $url
 * @return void
 */
function clf_base_mcekit_editor_style($url) {
	global $clf_base_options;
	if ( !empty($url) )
		$url .= ',';
	$wp_site_upload_directory = wp_upload_dir();
	$url .= $wp_site_upload_directory ['baseurl'].'/clf_base/css/'.$clf_base_options['style']['editor-mini'];
	
	return $url;
}

/**
 * clf_base_unstall_theme function.
 * 
 * @access public
 * @param mixed $theme
 * @return void
 */
function clf_base_unstall_theme($theme)
{
	// remove all the settings
	// delete_option("clf_base"); never do this.
}

/**
 * clf_base_fonts_and_colours_style_url function.
 * important fix for removing the version number for files that are uploaed to the uploads folder
 * @access public
 * @param mixed $url
 * @return void
 */
function clf_base_fonts_and_colours_style_url($url){
	
	return str_replace("?ver=-remove-version","",$url);
}

/**
 * clf_base_add_print_stylesheet function.
 * 
 * @access public
 * @return void
 */
function clf_base_add_print_stylesheet()
{
	 wp_enqueue_style( 'clf-base-print', get_bloginfo('stylesheet_directory')."/print.css",false,false,'print');

}

/** 
* Left for Future consideration, idea to edit the theme options from the front page
**********************************************************/ 

// add_action("wp_footer","clf_base_theme_options_footer");
function clf_base_theme_options_footer()
{
 global $clf_base_options;
?>
	<div id="footer_theme_options" style="position: fixed; z-index: 2000000000; background:#333; color:#FFF; right: 0pt; bottom: 0pt; cursor: pointer; border: 0pt none; content: normal; display: inline; height: 25px; left: auto; margin: 0pt; max-height: 25px; max-width: 62px; min-height: 25px; min-width: 62px; orphans: 2; outline: medium none; overflow: visible; padding: 0pt; page-break-after: auto; page-break-before: auto; page-break-inside: auto; table-layout: auto; text-indent: 0pt; top: auto; unicode-bidi: normal; vertical-align: baseline; visibility: visible; widows: 2; width: 65px;"><?php echo $clf_base_options['version']; ?></div>
	
<?php 
}









