<?php
/** 
 * Fonts and Colors
 *
 */
 
require_once('helper.php');
add_action('admin_init', 'clf_base_fonts_and_colors');


add_filter("clf_base_add_style_path",'clf_base_add_style_choice');

add_filter("clf_base_add_style_css_content",'clf_base_add_fonts_choices');
add_filter("clf_base_modify_style_css_content",'clf_base_modify_colours');
/* editor */
add_filter("clf_base_add_editor_style_css_content",'clf_base_add_editor_fonts_choices');
add_filter("clf_base_add_editor_style_css_content",'clf_base_modify_colours');
/**
 * clf_base_navigation function.
 * 
 * @access public
 * @return void
 */
function clf_base_fonts_and_colors()
{
	//add the section navigation 
	add_settings_section('fonts-and-colors', 'Fonts & Colors', 'clf_base_theme_options_fonts_and_colors', 'clf-base-theme-options');
	add_settings_field('clf-base-fonts-and-colors-style', 'Style Options', 'clf_base_theme_options_fonts_and_colors_style', 'clf-base-theme-options', 'fonts-and-colors');
	add_settings_field('clf-base-fonts-and-colors-fonts', 'Font Options', 'clf_base_theme_options_fonts_and_colors_fonts', 'clf-base-theme-options', 'fonts-and-colors');
	add_settings_field('clf-base-fonts-and-colors-colours', 'Colour Options', 'clf_base_theme_options_fonts_and_colors_colours', 'clf-base-theme-options', 'fonts-and-colors');

	wp_register_style('clf-base-css-ui-fonts-and-colors', get_bloginfo('stylesheet_directory').'/library/fonts-and-colors/panel.css');

	add_action('clf_base_admin_ui','clf_base_fonts_and_colors_styles');
}

function clf_base_add_style_choice($paths)
{
	global $clf_base_options;
	$paths[] = '/library/fonts-and-colors/css/'.$clf_base_options['fonts-and-colors']['style'].'.css';
	return $paths;
}


function clf_base_add_fonts_choices($style) {
	global $clf_base_options;

	// import google fonts 
	$style = clf_base_add_google_fonts( $clf_base_options['fonts-and-colors']['fonts']['body'],$clf_base_options['fonts-and-colors']['fonts']['heading'] ) . $style;
	$fonts = 'body {font-family:'. $clf_base_options['fonts-and-colors']['fonts']['body'].';}';

	$fonts .='h1, h2, h3, h4, h5, h6, big, #site-title {font-family:'. $clf_base_options['fonts-and-colors']['fonts']['heading'].';}';
	
	return $style." ".$fonts;
}

function clf_base_add_editor_fonts_choices($style)
{
	global $clf_base_options;
	
	// import google fonts 
	$style = clf_base_add_google_fonts( $clf_base_options['fonts-and-colors']['fonts']['body'],$clf_base_options['fonts-and-colors']['fonts']['heading'] ) . $style;

	$fonts = 'body.mceContentBody {font-family:'. $clf_base_options['fonts-and-colors']['fonts']['body'].';}';

	$fonts .='h1, h2, h3, h4, h5, h6, big {font-family:'. $clf_base_options['fonts-and-colors']['fonts']['heading'].';}';
	
	return $style." ".$fonts;
}

/**
 * clf_base_modify_colours function.
 * todo: This could be done better withe a array replace 
 * 		 - introduce more colors 
 * @access public
 * @param mixed $output
 * @return void
 */
function clf_base_modify_colours($output)
{
	global $clf_base_options;
	
	$colours = $clf_base_options['fonts-and-colors'];
	
	$primary = 		$colours['primary'];
	$secondary = 	$colours['secondary'];
	$alternate = 	$colours['alternate'];
	
	$primary_gradient = clf_base_colourMix($primary, 0.85, 255);
	$primary_lighten = clf_base_colourMix($primary, 0.65, 255);
	
	
	$output = str_replace("#002859; /* Primary Emphasis */", "#".$primary."; /* Primary Emphasis */", $output);
	$output = str_replace("#7491a3; /* Secondary Emphasis */", "#".$secondary."; /* Secondary Emphasis */", $output);
	$output = str_replace("#d1d9de; /* Alternate Background Colour */", "#".$alternate."; /* Alternate Background Colour */", $output);
	
	// Gradient on Full Width Drop Down Navigation
	$output = str_replace("-moz-linear-gradient(top, #0d1c41, #002859)", "-moz-linear-gradient(top, #".$primary_gradient.", #".$primary.")", $output); // FF
	$output = str_replace("-webkit-gradient(linear,left bottom,left top,color-stop(0, #0d1c41),color-stop(1, #002859));", "-webkit-gradient(linear,left bottom,left top,color-stop(0, #".$primary."),color-stop(1, #".$primary_gradient."));", $output); // Webkit
	$output = str_replace("Microsoft.gradient(startColorstr='#0d1c41', endColorstr='#002859')","Microsoft.gradient(startColorstr='#".$primary_gradient."', endColorstr='#".$primary."')", $output); // IE
	
	// Gradient on Spotlight Buttons
	$primary_darker = clf_base_colourMix($primary, 0.90, 0);
	$output = str_replace("background: -moz-linear-gradient(top, #002859 0%, #002859 50%, #00234E 51%, #002859 100%);","background: -moz-linear-gradient(top, #$primary 0%, #$primary 50%, #$primary_darker 51%, #$primary 100%);",$output);
	$output = str_replace("background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#002859), color-stop(50%,#002859), color-stop(51%,#00234E), color-stop(100%,#002859));","background: -webkit-gradient(linear, left top, left bottom, color-stop(0%,#$primary), color-stop(50%,#$primary), color-stop(51%,#$primary_darker), color-stop(100%,#$primary)); ", $output);
	
	$output = str_replace("filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#002859', endColorstr='#002859',GradientType=0 );","filter: progid:DXImageTransform.Microsoft.gradient( startColorstr='#$primary' , endColorstr='#$primary_darker',GradientType=0 );",$output);
	
	
	$output = str_replace("#405B72; /* Primary Lighten */", "#".$primary_lighten."; /* Primary Lighten */", $output);
	$output = str_replace("#0d1c41; /* Primary Darker */", "#".$primary_gradient."; /* Primary Darker */", $output);
	
	// mobile 
	return $output;
}

/**
 * clf_base_fonts_and_colors_styles function.
 * 
 * @access public
 * @return void
 */
function clf_base_fonts_and_colors_styles() {
	wp_enqueue_style('clf-base-css-ui-fonts-and-colors');
	
	// Javascript for the Look & Feel
	wp_enqueue_script('clf-base-fonts-and-colors-panel', get_bloginfo('stylesheet_directory').'/library/fonts-and-colors/panel.js', array('jquery'));
}

/**
 * clf_base_theme_options_fonts_and_colors function.
 * 
 * @access public
 * @return void
 */
function clf_base_theme_options_fonts_and_colors() {
	?>
	<h3>Preview</h3>
	<?php 
}

/**
 * clf_base_theme_options_fonts_and_colors_style function.
 * 
 * @access public
 * @return void
 */
function clf_base_theme_options_fonts_and_colors_style() {
	global $clf_base_options;
	?>
	<div class="explanation">
	<p>The CLF advanced theme offers a number of styles for your site.  Choose the style that suits your needs.</p>
	</div>
	<div class="options-shell options-fields">
	<div class="option">
		<label><input type="radio" name="clf_base[fonts-and-colors][style]" value="common" <?php checked('common', $clf_base_options['fonts-and-colors']['style']); ?>  />
		Common Look and Feel</label>
	</div>
	
	<div class="option ">
		<label><input type="radio" name="clf_base[fonts-and-colors][style]" value="border" <?php checked('border', $clf_base_options['fonts-and-colors']['style']); ?>   />
		Borders</label>
	</div>
	
	<?php

}

/**
 * clf_base_theme_options_fonts_and_colors_fonts function.
 * 
 * @access public
 * @return void
 */
function clf_base_theme_options_fonts_and_colors_fonts() {
	global $clf_base_options;
	$upload_dir = wp_upload_dir();
	$cssbaseurl = $upload_dir['baseurl'];
	
	?>
	<div class="explanation">
		<h3>Font &amp; Style Options</h3>
		<p>Choose from different font size scales, header and body fonts. </p><p>Fonts marked with an * are cross operating system compatible.</p>
	</div>
	<div id="simple-type">
	<div class="third">
	<label>Choose a size scale</label><br />
	<select id="typography-style" name="clf_base[fonts-and-colors][typography][style]" >
		<option value="default" <?php selected('default', $clf_base_options['fonts-and-colors']['typography']['style']); ?>>Default</option>
		<option value="linear" <?php selected('linear', $clf_base_options['fonts-and-colors']['typography']['style']); ?>>Linear</option>
		<option value="fibonacci" <?php selected('fibonacci', $clf_base_options['fonts-and-colors']['typography']['style']); ?>>Fibonacci</option>
	</select>
	</div>
	<div class="third">
	<label>Headings Fonts</label><br />
	<select id="heading-fonts" name="clf_base[fonts-and-colors][fonts][heading]">
		<?php echo clf_base_font_select("heading");?>
	</select>
		</div>
	<div class="third">	
	<label>Body Text Fonts</label><br />	
	<select id="body-fonts" name="clf_base[fonts-and-colors][fonts][body]">
		<?php 
		echo clf_base_font_select('body');?>
	</select>
	</div>
	
	</div>
	<div>
	<?php // preview: Heading font:<span id="heading-font-preview"></span>, Body font: <span id="body-font-preview"></span>; ?>
	<iframe id="font-preview" src="<?php echo get_stylesheet_directory_uri(); ?>/library/fonts-and-colors/preview.php?body=<?php echo $clf_base_options['fonts-and-colors']['fonts']['body']; ?>&heading=<?php echo $clf_base_options['fonts-and-colors']['fonts']['heading']; ?>&style=<?php echo $clf_base_options['fonts-and-colors']['typography']['style']; ?>&hcolor=<?php echo $clf_base_options['fonts-and-colors']['primary']; ?>" ></iframe>
	</div>
	<div class="hide-advanced">
	<label><input type="checkbox" value="1" name="clf_base[fonts-and-colors][fonts][include-bold]" <?php checked( $clf_base_options['fonts-and-colors']['fonts']['include-bold']); ?> /> Include the bold font from google fonts if it is supported. Note that this increases the page load time.</label>
	</div>
	</div>

	<?php

}


/**
 * clf_base_font_option function.
 * 
 * @access public
 * @param mixed $font
 * @param string $size. (default: "1.4")
 * @param bool $serif. (default: true)
 * @param bool $web_safe. (default: true)
 * @return void
 */
function clf_base_font_option($font,$type,$serif=true,$web_safe=true) {
	global $clf_base_options;
	$mark_as_web_safe 	= ( $web_safe ? " *":"" );
	$serif_fonts 		= ( $serif ? ",georgia,serif":",arial,sans-serif" );
	
	?>
		<option value="<?php echo $font.$serif_fonts; ?>"  <?php selected($font.$serif_fonts, $clf_base_options['fonts-and-colors']['fonts'][$type]); ?>  ><?php echo $font."".$mark_as_web_safe ?></option>
	<?php
}


/**
 * clf_base_font_select function.
 * 
 * @access public
 * @return void
 */
function clf_base_font_select($type) {

	
?>
	<optgroup label="Sans-Serif Fonts">
			<?php echo clf_base_font_option("Arial",$type,false); ?>
			<?php echo clf_base_font_option("Arial Black",$type,false); ?>
			<?php echo clf_base_font_option("Arial Narrow",$type,false); ?>
			<?php echo clf_base_font_option("Century Gothic",$type,false); ?>
			<?php echo clf_base_font_option("Courier New",$type,false); ?>
			<?php echo clf_base_font_option("Gill Sans",$type,false); ?>
			<?php echo clf_base_font_option("Impact",$type,false); ?>		
			<?php echo clf_base_font_option("Lucida Console",$type,false); ?>
			<?php echo clf_base_font_option("Lucida Grande",$type,false); ?>
			<?php echo clf_base_font_option("Tahoma",$type,false); ?>
			<?php echo clf_base_font_option("Trebuchet MS",$type,false); ?>
			<?php echo clf_base_font_option("Verdana",$type,false); ?>
			<?php echo clf_base_font_option("Calibri",$type,false,false); ?>
			<?php echo clf_base_font_option("Candara",$type,false,false); ?>
			<?php echo clf_base_font_option("Helvetica",$type,false,false); ?>
			<?php echo clf_base_font_option("Franklin Gothic Medium",$type,false,false); ?>
			<?php echo clf_base_font_option("Rockwell",$type,false,false); ?>
		</optgroup>
		<optgroup label="Serif Fonts">
			<?php echo clf_base_font_option("Georgia",$type,false); ?>
			<?php echo clf_base_font_option("Times New Roman",$type,false); ?>
			<?php echo clf_base_font_option("Palatino",$type,false); ?>
			<?php echo clf_base_font_option("Century Schoolbook",$type,false,false); ?>
			<?php echo clf_base_font_option("Bookman Old Style",$type,false,false); ?>
			<?php echo clf_base_font_option("Baskerville",$type,false,false); ?>
			<?php echo clf_base_font_option("Cambria",$type,false,false); ?>
		</optgroup>
		<optgroup label="Google fonts">
			<?php foreach(clf_base_supported_google_fonts() as $font ):
			echo clf_base_font_option($font,$type,false); 
			endforeach; ?>
		</optgroup>

<?php
}

/**
 * clf_base_theme_options_fonts_and_colors_colours function.
 * 
 * @access public
 * @return void
 */
function clf_base_theme_options_fonts_and_colors_colours() {
	global $clf_base_options;
	?>
	<div id="theme-colours">
		<div class="explanation">
			<h3>Colour Options</h3>
			<p>Choose primary emphasis, secondary emphasis and alternate background colours to match your unit's brand.</p>
		</div>
		
		
		<div class="option-third">
			<label for="primary-color">Primary Colour</label><br />
			#<input id="primary-color" size="6" maxlength="6" name="clf_base[fonts-and-colors][primary]" type="text" value="<?php echo $clf_base_options['fonts-and-colors']['primary']; ?>">
			<div id="primary-color-box" class="pallet"  style="background:#<?php echo $clf_base_options['fonts-and-colors']['primary']; ?>">
			</div>
			<p>The primary emphasis colour is used in places like the headings and navigation that require a stronger emphasis.  An ideal primary emphasis colour should match your unit's brand colour's hue, while being dark enough to stand out on light coloured backgrounds.</p>
		</div>
		
		<div class="option-third">
			<label for="secondary-color">Secondary Colour</label><br />
		#<input id="secondary-color"  size="6" maxlength="6" name="clf_base[fonts-and-colors][secondary]" type="text" value="<?php echo $clf_base_options['fonts-and-colors']['secondary']; ?>">
			<div id="secondary-color-box" class="pallet" style="background:#<?php echo $clf_base_options['fonts-and-colors']['secondary']; ?>">
			</div>
			<p>The secondary emphasis colour is used in places like text links and sometimes background to provide a lower level of emphasis.  An ideal secondary emphasis colour should match your unit's brand colour's hue, while being lighter than the primary emphasis colour to reduce emphasis.</p>
		</div>
		<div class="option-third">
			<label for="alternate-color">Background Colour</label><br />
		#<input id="alternate-color"  size="6" maxlength="6" name="clf_base[fonts-and-colors][alternate]" type="text" value="<?php echo $clf_base_options['fonts-and-colors']['alternate']; ?>">
			<div id="alternate-color-box" class="pallet" style="background:#<?php echo $clf_base_options['fonts-and-colors']['alternate']; ?>">
			</div>
			<p>The alternate background colour is used to provide differentiation between blocks of text, and sometimes as a border colour.  An ideal alternate background colour should be very light - light enough to look almost white.</p>
			
		</div>
		
		<hr class='clear' />
		<div class="half">
			<p>The UBC top level brand uses <br /><a href="#reset" id="reset-colors-vancouver">reset to UBC Vancouver colours</a><br />
			<br />#<input type="text" value="002859" onfocus="this.value='002859'" size="6" onblur="this.value='002859'" /> 
			<span style="background-color: #002859;  ">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span> as Primary color <br /></p>
			
			<p><br />#<input type="text" value="7491a3" onfocus="this.value='7491a3'" size="6" onblur="this.value='7491a3'" /> 
			<span style="background-color: #7491a3;  ">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>  as Secondary color<br /></p>
			
			<p><br />#<input type="text" value="d1d9de" onfocus="this.value='d1d9de'" size="6" onblur="this.value='d1d9de'" /> <span style="background-color: #d1d9de;  ">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span> Background colour</p>
		</div>
		<div class="half">
			<p>The UBC top level brand uses<br /> <a href="#reset" id="reset-colors-okanagan">reset to UBC Okanagan colours</a><br />
			<br />#<input type="text" value="3b4629" onfocus="this.value='3b4629'" size="6" onblur="this.value='3b4629'" /> 
			<span style="background-color: #3b4629;  ">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span> as Primary color<br /></p>
			
			<p><br />#<input type="text" value="61704b" onfocus="this.value='61704b'" size="6" onblur="this.value='61704b'" /> 
			<span style="background-color: #61704b;  ">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span>  as Secondary color<br /></p>
			
			<p><br />#<input type="text" value="ecf0e0" onfocus="this.value='ecf0e0'" size="6" onblur="this.value='ecf0e0'" /> <span style="background-color: #ecf0e0;  ">&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;</span> Background colour</p>
		</div>
			<?php
}
