<?php 
/** 
 * Frontpage
 *
 */
add_action('admin_init', 'clf_base_frontpage');


add_filter("clf_base_add_style_path",'clf_base_add_frontpage_styles');	
/**
 * clf_base_frontpage function.
 * 
 * @access public
 * @return void
 */
function clf_base_frontpage() {
	add_settings_section('frontpage', 'Frontpage', 'clf_base_theme_options_frontpage', 'clf-base-theme-options');
	
	add_settings_field('clf-base-frontpage-select-layout', 'Frontpage Layout', 'clf_base_theme_options_frontpage_options', 'clf-base-theme-options', 'frontpage');
	add_settings_field('clf-base-frontpage-spotlight', 'Spotlight Rotation Options', 'clf_base_theme_options_spotlight_rotation_options', 'clf-base-theme-options', 'frontpage');
	add_settings_field('clf-base-frontpage-content-area', 'Content Area', 'clf_base_theme_options_content_area_options', 'clf-base-theme-options', 'frontpage');

	// include styles 
	wp_register_style('clf-base-css-ui-frontpage', get_bloginfo('stylesheet_directory').'/library/frontpage/panel.css');
	add_action('clf_base_admin_ui','clf_base_fontpage_ui');
}

function clf_base_add_frontpage_styles($paths)
{
	$paths[] = '/library/frontpage/css/layout.css';
	
	return $paths;
}

/**
 * clf_base_fontpage_ui function.
 * 
 * @access public
 * @return void
 */
function clf_base_fontpage_ui() {
	wp_enqueue_style( 'clf-base-css-ui-frontpage');
	wp_enqueue_style( 'clf-base-frontpage-layout');
}

add_action('after_wp_tiny_mce', 'clf_base_frontpage_load_script_after_tinymce');

/**
 * clf_base_frontpage_load_script_after_tinymce function.
 * 
 * @access public
 * @return void
 */
function clf_base_frontpage_load_script_after_tinymce(){
	global $clf_base_options;
	$column_number = sizeof($clf_base_options['frontpage']['content_area']);
	
	if(isset($_GET['add_column']))
		$column_number++;
	
	$columns = array();
	while($column_number):
		
		if( !(isset($_GET['remove_column']) && ($column_number == $_GET['remove_column'])) )
			$columns[] = $column_number;
			
		$column_number--;
	endwhile;
	
	echo '<script type="text/javascript">
	/* <![CDATA[ */
		var CLFBaseFrontpage = {"columns":"'.implode(",",$columns).'","mode":"auto","id":"'.$columns[0].'"};
	/* ]]> */
	</script>';
	echo '<script type="text/javascript" src="'.get_bloginfo('stylesheet_directory').'/library/frontpage/panel.js"></script>';
	
	
}
/**
 * clf_base_tiny_filter_remove_fullscreen function.
 * 
 * @access public
 * @param mixed $initArray
 * @return void
 */
function clf_base_tiny_filter_remove_fullscreen($initArray){
	$initArray["theme_advanced_buttons1"] = str_replace(',fullscreen', '', $initArray["theme_advanced_buttons1"]);
	return $initArray;
	
}
/**
 * clf_base_theme_options_frontpage function.
 * 
 * @access public
 * @return void
 */
function clf_base_theme_options_frontpage() {
?>
	<div class="explanation">
		<p>Frontpage Layout</p>
		<p>The front page of a website often has unique requirements in terms of layouts and content.  Use one of the options below to set up a custom front page for your site.  A custom front page has three components: <em>the spotlight rotation, the frontpage widget area, and front page content areas</em>.</p>
		<p><strong>Spotlight Rotation:</strong> A rotating slideshow of headlines from a select category.</p>
		<p><strong>Frontpage Widget Area:</strong> A widget area unique to the front page.</p>
		<p><strong>Content Area:</strong> An area for text or HTML input, which can be split into a number of columns.</p>
		<p>Note: if you do not wish to use a custom front page, choose <em>Default Homepage.</em> This will give you the WordPress default homepage with a layout based on your global layout settings.</p>
	</div>
	<?php
}

/**
 * clf_base_theme_options_frontpage_options function.
 * 
 * @access public
 * @return void
 */
function clf_base_theme_options_frontpage_options() {
	global $clf_base_options;
	
	$column_number = sizeof($clf_base_options['frontpage']['content_area']);
	
	if(isset($_GET['add_column']))
		$column_number++;
		
	if(isset($_GET['remove_column']))
		$column_number--;
	?>
		<div class="options-shell">
		<div class="option half frontpage-option-1 <?php echo $clf_base_options['layout'];?>">
			<label><input type="radio" name="clf_base[frontpage][option]" value="1" <?php checked('1', $clf_base_options['frontpage']['option']); ?>/> Option 1</label>
			<div class="dynamic-content">Spotlight Rotation</div>
			<div class="frontpage-widget"> Frontpage <br /> Widget Area</div>
			<div class="static-content columns-<?php echo $column_number; ?>">Content Area<br />
			<?php 
		$count_column = 0;
		while($count_column < $column_number): $count_column++;?>
		<div class="preview-column"><?php echo $count_column; ?></div>
		<?php  endwhile; ?>
			</div>
		</div>
		<div class="option half  frontpage-option-2 <?php echo $clf_base_options['layout'];?>">
			<label><input type="radio" name="clf_base[frontpage][option]" value="2" <?php checked('2', $clf_base_options['frontpage']['option']); ?>/> Option 2</label>
			<div class="dynamic-content">Spotlight Rotation</div>
			<div class="frontpage-widget"> Frontpage <br /> Widget Area</div>
			<div class="static-content columns-<?php echo $column_number; ?>">
			Content Area<br />	
			<?php 
		$count_column = 0;
		while($count_column < $column_number): $count_column++;?>
		<div class="preview-column"><?php echo $count_column; ?></div>
		<?php  endwhile; ?>
			</div>
		</div>
		<div class="option half  frontpage-option-3 <?php echo $clf_base_options['layout'];?>">
			<label><input type="radio" name="clf_base[frontpage][option]" value="3" <?php checked('3', $clf_base_options['frontpage']['option']); ?>/> Option 3</label>
			<div class="dynamic-content">Spotlight Rotation</div>
			<div class="frontpage-widget"> Frontpage <br /> Widget Area</div>
			<div class="static-content columns-<?php echo $column_number; ?>">Content Area<br />
			<?php 
		$count_column = 0;
		while($count_column < $column_number): $count_column++;?>
		<div class="preview-column"><?php echo $count_column; ?></div>
		<?php  endwhile; ?>
			</div>
		</div>
		<div class="option half  ">
			<label><input type="radio" name="clf_base[frontpage][option]" value="0" <?php checked('0', $clf_base_options['frontpage']['option']); ?>/> Default Front page </label>
			<p>Based on your <a href="<?php echo admin_url('options-reading.php'); ?>" title="Front page displays">Front page displays</a> it either shows a static page or blog</p> 
		</div>
		</div>
	<?php
}

/**
 * clf_base_theme_options_spotlight_rotation_options function.
 * 
 * @access public
 * @return void
 */
function clf_base_theme_options_spotlight_rotation_options() {
	global $clf_base_options;
	extract($clf_base_options['frontpage']['spotlight']);
	?>
	<div class="clear options-shell">
		<div class="explanation">
			<h3>Spotlight Rotation Style</h3>
			<p>Change the appearance of the spotlight rotation.  Use the UBC standard spotlight rotation, or the gallery style with horizontally panning slides.</p>
			<p>To place an image inside the slideshow you need to add a custom image to the post.</p>
		</div>
		<div class="option option-third">
			<label>
				<input type="radio" name="clf_base[frontpage][spotlight][lookandfeel]" value="standard" <?php checked('standard', $lookandfeel); ?>/> 
			UBC.ca Standard Spotlight
				<img src="<?php bloginfo("stylesheet_directory"); ?>/library/frontpage/spotlight/standard_spotlight.jpg" />
			</label>
		</div>
		<div class="option option-third">
			<label>
				<input type="radio" name="clf_base[frontpage][spotlight][lookandfeel]" value="gallery" <?php checked('gallery', $lookandfeel); ?>/> Horizontally Sliding Gallery
				<img src="<?php bloginfo("stylesheet_directory"); ?>/library/frontpage/spotlight/gallery_spotlight.jpg" />
			</label>
		</div>
		<div class="option option-third">
			<label>
				<input type="radio" name="clf_base[frontpage][spotlight][lookandfeel]" value="blank" <?php checked('blank', $lookandfeel); ?>/> Blank Sliding 
				<img src="<?php bloginfo("stylesheet_directory"); ?>/library/frontpage/spotlight/blank_spotlight.jpg" />
			</label>
		</div>
		<div class="option option-third">
			<label>
				<input type="radio" name="clf_base[frontpage][spotlight][lookandfeel]" value="transparent" <?php checked('transparent', $lookandfeel); ?>/> Transparent Sliding 
				<img src="<?php bloginfo("stylesheet_directory"); ?>/library/frontpage/spotlight/transparent_spotlight.png" />
			</label>
		</div>
		<div class="option option-third">
			<label>
				<input type="radio" name="clf_base[frontpage][spotlight][lookandfeel]" value="multi" <?php checked('multi', $lookandfeel); ?>/> Multi post Sliding 
				<img src="<?php bloginfo("stylesheet_directory"); ?>/library/frontpage/spotlight/multi_spotlight.jpg" />
			</label>
		</div>

	</div>
	
	
	
	
	<div class="clear half">
	<div class="explanation">
	<h3><label>Category to be displayed</label></h3>
	<p>The spotlight rotation draws its content from a specific category.  Specify the category you want it to draw from.</p>
	</div>
		<?php wp_dropdown_categories(array(
				"hierarchical"=>1,
				"name"=>"clf_base[frontpage][spotlight][category]",
				"selected"=>$category)
				);
			?>
			<a href="edit-tags.php?taxonomy=category" target="_blank">add category</a>
	</div>
	<div class="half">
	<div class="explanation">
		<h3><label>Number of slides</label></h3>
		<p>Limit the number of slides in the spotlight rotation.</p>
		<p><strong>Note</strong>: the spotlight rotation will display the latest posts from the specified category, up to the number of slides you set here.</p>
	</div>
	
	
	<select name="clf_base[frontpage][spotlight][number_of_slides]">
	<?php for($i=1; $i<21; $i++){?> "<option value="<?php echo $i; ?>" <?php selected( $number_of_slides, $i); ?>><?php echo $i; ?></option><?php  ;} ?>
	</select>
			
	</div>
	<div class="half">
	<div class="explanation">
		<h3><label>Read More Button</label></h3>
		<p>Enables the "read more"" button on each slide.</p>
	</div>
			<label><input type="checkbox" name="clf_base[frontpage][spotlight][read-more][checked]" value="1" <?php checked(isset($clf_base_options['frontpage']['spotlight']['read-more']['checked'])); ?> /> Display the read more button</label><br />
			<label>Button text:<br /><?php 
			$read_more = ( isset( $clf_base_options['frontpage']['spotlight']['read-more']['text'] ) ? $clf_base_options['frontpage']['spotlight']['read-more']['text'] : "" );
?>			<input type="text" name="clf_base[frontpage][spotlight][read-more][text]" value="<?php echo esc_attr($read_more); ?>" /></label>
			<br /> leave blank for 'Read More' 
			
	</div>
	<div class="half">
	<div class="explanation">
			<h3><label>Image Height</label></h3>
			<p>Set the slides image height in pxs, Option 2 default height is 200px and 940px width<br /><br />  Option 1 and Option 3 default height is 300px and 560px width.</p>
		
	</div>
			<?php $height = (isset($height)? $height : false ); ?>
			<label><input type="text" name="clf_base[frontpage][spotlight][height]" size="4" value="<?php echo esc_attr($height); ?>" /> px </label><br />
			leave blank for default,<br /> Option 2 default height is 200px.<br />  Option 1 and Option 3 default height is 300px.
	</div>
	<br /><br />
	<div class="hide-advanced">
		<div class="half clear">
			
			<label>Transition duration time</label><br />
			<input type="text" class="small-text" name="clf_base[frontpage][spotlight][transition_duration]" value="<?php echo esc_attr($transition_duration); ?>"   /> milliseconds<br />
			<span>The amount of time it take to switch between slides</span>	
		</div>
		<div class="half">
			
			<label>Slide duration time</label><br />
			<input type="text" class="small-text" name="clf_base[frontpage][spotlight][slide_duration]" value="<?php echo esc_attr($slide_duration); ?>"   /> sec<br />
			<span>The amount of time the slide is going to be displayed</span>
		</div>
		<hr />
		<div class="half">
			
			<label for="slide-effect">Slide Effects</label><br />
			<?php $effect = (isset($effect)? $effect : false); ?>
			<select name="clf_base[frontpage][spotlight][effect]" id="slide-effect" >
				<option value="0" <?php selected($effect, false); ?> >Default</option>
				<option value="fade" <?php selected($effect, "fade"); ?>>Fade</option>
				<option value="growX" <?php selected($effect, "growX"); ?>>Grow</option>
				<option value="scrollHorz" <?php selected($effect, "scrollHorz"); ?>>Scroll</option>
				<option value="turnLeft" <?php selected($effect, "turnLeft"); ?>>Turn Left</option>
				<option value="uncover" <?php selected($effect, "uncover"); ?>>Uncover</option>
			</select> 
			<span>Specify a slide transition effect.</span>
		</div>
		
		<div class="half">
			<label for="slide-order-by">Order Slides By</label><br />
			<?php $order_by = ( isset($order_by) || $order_by != 'date' ? $order_by : false); ?>
			<select name="clf_base[frontpage][spotlight][order_by]" id="slide-order-by">
				<option value="date" <?php selected($order_by, false); ?> >Default - Date</option>
				<option value="rand" <?php selected($order_by, "rand"); ?>>Random</option>
				<option value="modified" <?php selected($order_by, "modified"); ?>>Modified Date</option>
				<option value="title" <?php selected($order_by, "title"); ?>>Title</option>
			</select><br />
			<span>Specify a slide transition effect.</span>
			
			<label>Order Slides</label><br />
			<?php $order = ( isset($order) ? $order : 'DESC'); ?>
			<label> <input type="radio" name="clf_base[frontpage][spotlight][order]" <?php checked($order, "DESC"); ?> value="DESC" /> Descending (3, 2, 1) </label>
			<label> <input type="radio" name="clf_base[frontpage][spotlight][order]" <?php checked($order, "ASC"); ?> value="ASC" /> Ascending (1, 2, 3) </label>
		</div>
		<hr />
		<div class="half">
			<label>
			<?php $force_width = ( isset($force_width) ? $force_width : false ); ?>
			Force width<br /> <input type="text" size="4" name="clf_base[frontpage][spotlight][force_width]" value="<?php echo esc_attr($force_width); ?>" > px </label><br />
			Force the width of the slides in the spotlight, note that this functionality is usually accompanied with changes to the stylesheet. Leave field blank for the default width.<br />
			
			
		</div>
		<div class="half">
			<label for="link-to">
			<?php $remove_link_to = ( isset($remove_link_to) ? true : false ); ?>
			<input type="checkbox" name="clf_base[frontpage][spotlight][remove_link_to]" value="1" <?php checked($remove_link_to); ?> id="link-to"> Remove the link from the slides.</label><br />
				
		</div>
		
	</div>
	

	
	<?php
}
/**
 * clf_base_theme_options_content_area_options function.
 * 
 * @access public
 * @return void
 */
function clf_base_theme_options_content_area_options() {
	global $clf_base_options;
	$column_number = sizeof($clf_base_options['frontpage']['content_area']);
	
	if(isset($_GET['add_column']))
		$column_number++;
	if(isset($_GET['remove_column']))
		$column_number--;
	
	$count = 1;
	$count_column = 0;
	
	?>
	<div class="explanation">
		<h3>Frontpage Content Area</h3>
		<p>Write content for the frontpage.  Use the add column button to add columns to the content area.  The content area can be divided into a maximum of five columns.</p>
		<p><strong>Note</strong>: You can use <em>shortcodes</em> here to bring in dynamic content.  For example, the [feed] shortcode is commonly used to bring in a list of headlines from other blogs or your own blog.</p>
		<p>Sample usage: the shortcode [feed url="http://www.publicaffairs.ubc.ca/category/media-releases/feed/"] will generate a list of the latest headlines of UBC news, drawing from Public Affairs' media release RSS feed.</p>
	</div>
	<div id="fontpage-columns-show" class="columns-<?php echo $column_number; ?>"><?php 
		$count_column = 0;
		while($count_column < $column_number): $count_column++;?>
			<div class="preview-column"><?php echo $count_column; ?></div>
		<?php  
		endwhile; ?>
	</div>
	<div id="fontpage-columns">
	<?php 
		$wysiwig_settings = array(
			'textarea_name' => 'clf_base[frontpage][content_area][]',
			'textarea_rows' => 10
		);
	
	if($column_number < 2): 
		$count++;
	?>
		<div class="frontpage-column">
		<label ><?php echo (isset($_GET['add_column']) ? "Column" : 'Main Content');?></label><br />
		<?php wp_editor($clf_base_options['frontpage']['content_area'][0], 'wysiwig-0', $wysiwig_settings); ?>
		</div>
	<?php 
	else: 
		
		foreach($clf_base_options['frontpage']['content_area'] as $column_content): 
			$remove_column = (isset($_GET['remove_column']) ? $_GET['remove_column'] : NULL);
			if($count != $remove_column): ?>
			<div class="frontpage-column">
				<label >Column <?php echo $count; ?></label> <a href="?page=clf-base-theme-options&remove_column=<?php echo $count; ?>#fontpage-columns" class="remove-column">Remove</a><br />
				<?php wp_editor($clf_base_options['frontpage']['content_area'][$count-1], 'wysiwig-'.($count-1), $wysiwig_settings); ?>
			</div>
			<?php 
			endif;
			$count++;
		endforeach; 
	endif;
	
	// add another column 
	if(isset($_GET['add_column'])): ?>
		<div class="frontpage-column">
			<label >Column</label> <a href="?page=clf-base-theme-options&remove_column=<?php echo $count; ?>#fontpage-columns" class="remove-column">Remove</a></a><br />
			<?php wp_editor('', 'wysiwig-'.$count, $wysiwig_settings); ?>
			
		</div>
	<?php 
	endif;
	?>
	</div>
	<?php 
	
	// you can't add more 
	if($column_number < 5) : ?>
		<div id="add-column-text">
			<p>You can divide content into equal width columns</p>
			<p id="add-column"><a href="?page=clf-base-theme-options&add_column=1#add-column" class="button">Add a Column</a></p>
		</div>
	<?php 
	
	endif; 
	
}