<?php 


add_action('init','clf_base_spotlight_init');
add_shortcode("slideshow","clf_base_spotlight");

add_filter("clf_base_add_style_path",'clf_base_add_spotlight_style');



global $clf_base_spotlight_id; // this is used to that the shortcodes can be placed into myltipe places at the same time 

/**
 * clf_base_spotlight_init function.
 *  add the css files and js files 
 * @access public
 * @return void
 */
function clf_base_spotlight_init() {

	// register the spotlight functions
	if(!is_admin()):
		wp_enqueue_script('clf-base-spotlight', get_bloginfo('stylesheet_directory').'/library/frontpage/spotlight/js/spotlight.js',array('jquery'));
	endif;
}


/**
 * clf_base_add_spotlight_style function.
 * 
 * @access public
 * @param mixed $paths
 * @return void
 */
function clf_base_add_spotlight_style($paths) {
	$paths[] = '/library/frontpage/spotlight/css/spotlight.css';
	return $paths;
}


/**
 * clf_base_spotlight_defaults function.
 * 
 * @access public
 * @return void
 */
function clf_base_spotlight_defaults() {
	global $clf_base_options;
	
	$spotlight_atts = array(
		'width' 	=> null,
		'height' 	=> null,
		'category' 	=> $clf_base_options['frontpage']['spotlight']['category'],
		'lookandfeel' 		=> $clf_base_options['frontpage']['spotlight']['lookandfeel'],
		'maxslides' => $clf_base_options['frontpage']['spotlight']['number_of_slides'],
		'timeout' 	=> $clf_base_options['frontpage']['spotlight']['slide_duration'],
		'speed'   	=> $clf_base_options['frontpage']['spotlight']['transition_duration'],
		'frontpage_option' 	=> null,
		'effect'  	=> $clf_base_options['frontpage']['spotlight']['effect'],
		'read_more_text' 	=> $clf_base_options['frontpage']['spotlight']['read-more']['text'],
		'read_more_check' 	=> $clf_base_options['frontpage']['spotlight']['read-more']['checked'],
		'order_by' 	=> ($clf_base_options['frontpage']['spotlight']['order_by'] ? $clf_base_options['frontpage']['spotlight']['order_by'] : "date"),
		'order' 	=> ($clf_base_options['frontpage']['spotlight']['order'] ? $clf_base_options['frontpage']['spotlight']['order'] : "DESC"),
		'remove_link_to'	=> ($clf_base_options['frontpage']['spotlight']['remove_link_to'] ? $clf_base_options['frontpage']['spotlight']['remove_link_to'] : false)
	);
	return $spotlight_atts;
}


/**
 * clf_base_spotlight function.
 * this function is also the shotcode function 
 * @access public
 * @param mixed $atts. (default: null)
 * @return void
 */
function clf_base_spotlight($atts=null) {

	global $clf_base_options,$clf_base_spotlight_id;
	
	
	$clf_base_spotlight_id++;
	
	$spotlight_defaults_array = clf_base_spotlight_defaults();
	
	if(is_array($atts)):
		foreach($spotlight_defaults_array as $key => $value):
			if(empty($atts[$key])) 
				$atts[$key] = $spotlight_defaults_array[$key]; 
		endforeach;
		
	else:
		$atts = $spotlight_defaults_array;
	endif;
	
	$category = "";
	if(is_numeric($atts['category'])):
		$category = "&cat=".$atts['category'];
	elseif(!empty($atts['category'])):
		$category = "&category_name=".$atts['category'];
	endif;
	
	$atts['query'] ='posts_per_page='.$atts['maxslides'].$category."&orderby=".$atts['order_by']."&order=".$atts['order'];
	
	// Getting thumbnail sizes
	if($atts['frontpage_option'] == '2') { // Full width frontpage option? 
		$atts['width'] = 940;
		$atts['height'] = ($clf_base_options['frontpage']['spotlight']['height'] ? $clf_base_options['frontpage']['spotlight']['height'] : 200);
		
	} elseif( $atts['frontpage_option'] == '1' || $atts['frontpage_option'] == '3' ) { // ... or the 560px width frontpage option?
		$atts['width'] = 560;
		$atts['height'] = ($clf_base_options['frontpage']['spotlight']['height'] ? $clf_base_options['frontpage']['spotlight']['height'] : 300);
		
	}
	
	// Getting Max # of slides on spotlight
	$atts['maxslides'] = ( !is_null($atts['maxslides']) ? $atts['maxslides'] : '7');	
	
	$atts = apply_filters("clf_base_sportlight_attr", $atts );
	/* Switch to functions which handle individual look-and-feel types */
	switch ($atts['lookandfeel']) {
	    case "gallery":
	       	return str_replace("\r\n", '',clf_base_spotlight_gallery($atts) );
	    break;
	    case "blank":
	    	return str_replace("\r\n", '',clf_base_spotlight_blank($atts) );
	    break;
	    case "transparent":
	    	return str_replace("\r\n", '',clf_base_spotlight_transparent($atts) );
	    break;
	    case "multi":
	    	return str_replace("\r\n", '',clf_base_spotlight_multi($atts) );
	    break;
	    case "mobile":
	    	return str_replace("\r\n", '',clf_base_spotlight_mobile($atts) );
	    break;
	    default:
	    	return str_replace("\r\n", '',clf_base_spotlight_standard($atts) );
	}
	
}
/**
 * clf_base_spotlight_standard function.
 * 
 * @access public
 * @param mixed $atts
 * @return void
 */
function clf_base_spotlight_standard($atts) {
	global $clf_base_options,$clf_base_spotlight_id, $posts,$post;
	
	
	extract($atts);
	
	//jquery.cycle plugin option parameters.
	$jquery_cycle['fx'] = ($effect ? $effect : 'fade');
	
	
	$jquery_cycle['timeout'] = (is_numeric($timeout)) ? intval($timeout)*1000 : '6000';
	$jquery_cycle['speed'] = (is_numeric($speed)) ? intval($speed) : '200';
	
	$html .= '<div class="clf-base-spotlight clf-base-standard-spotlight" id="clf-base-spotlight-'. $clf_base_spotlight_id.'">';
	
	$maxheight = 300;
	
	// Query for Posts in the category
	$spotlight_query = new WP_Query($query);
	
	// Abstracted the Loop Away in clf_base_spolight_wploop();
	$html.=	clf_base_spotight_wploop($spotlight_query,$atts);
	$count = $spotlight_query->post_count;
	//Reset Query
	wp_reset_query();
 	ob_start(); // Start Output Buffer to contain spotlight code.
 	if($count > 1):
	?>
	<div class="controls">
		<a href="#next" id="play-pause-slides-<?php echo $clf_base_spotlight_id; ?>" class=" pause"><span>&#10073; &#10073;</span></a> 
		<a href="#previous-slide" id="previous-slide-<?php echo $clf_base_spotlight_id; ?>" class="previous-slide"><span>&laquo;</span></a> 
		<span id="slider-info-<?php echo $clf_base_spotlight_id; ?>" class="slider-info">1 / <?php echo $count; ?></span> 
		<a href="#next-slide" id="next-slide-<?php echo $clf_base_spotlight_id; ?>" class="next-slide"><span>&raquo;</span></a>
	</div>
	<?php endif; ?>
	</div>
		
		<script  type='text/javascript'>
		/* <![CDATA[ */
		/* Javascript Adaptive Setting of Width and Height */
		<?php if($width==null): ?>
			var width = jQuery("#clf-base-spotlight-<?php echo $clf_base_spotlight_id; ?>").width();
		<?php else: ?>	
			var width = <?php echo $width; ?>;
		<?php endif; ?>
		
		<?php $height = ($height!=null) ? $height : $maxheight; ?>
		
		
		
		jQuery("#clf-base-spotlight-<?php echo $clf_base_spotlight_id; ?>, #clf-base-spotlight-<?php echo $clf_base_spotlight_id; ?> div.slide, #clf-base-spotlight-<?php echo $clf_base_spotlight_id; ?> div.story-slide").css({
			'width': width+'px',
			'height':'<?php echo $height+99; ?>px'
		});
		
		jQuery("#clf-base-spotlight-<?php echo $clf_base_spotlight_id; ?>").find('.overlay-below').css({ 'width':width+'px' });
		jQuery("#clf-base-spotlight-<?php echo $clf_base_spotlight_id; ?>").find('.overlay, .overlay-below').css({ 'top':'<?php echo $height; ?>px' });
		jQuery("#clf-base-spotlight-<?php echo $clf_base_spotlight_id; ?>").find('.overlay').css({ 'width': <?php echo $width-155; ?> });
		<?php if($count > 1): ?>
		jQuery("#clf-base-spotlight-<?php echo $clf_base_spotlight_id; ?>").cycle({
			<?php 
			foreach($jquery_cycle as $attrkey => $attrvalue) {
				echo $attrkey.": '".$attrvalue."',";
			}
			?>
		    height: 'auto',
		    slideExpr:  "div.slide",
		    next: 	"#next-slide-<?php echo $clf_base_spotlight_id; ?>",
		    prev: 	"#previous-slide-<?php echo $clf_base_spotlight_id; ?>",
		    after:  function(currSlideElement, nextSlideElement, options, forwardFlag) 
        	{	
            	jQuery('#slider-info-<?php echo $clf_base_spotlight_id; ?>').text((options.currSlide + 1).toString() + ' / ' +options.slideCount);
        	}
		});
		
		/* Play & Pause Buttons */
		jQuery('#play-pause-slides-<?php echo $clf_base_spotlight_id; ?>').toggle(
		function() { 
			jQuery('#clf-base-spotlight-<?php echo $clf_base_spotlight_id; ?>').cycle('pause'); 
			jQuery(this).attr("class","play").html("&#9654;");
			return false;
		},
		function() { 
			jQuery("#clf-base-spotlight-<?php echo $clf_base_spotlight_id; ?>").cycle('resume');
    		jQuery(this).attr("class","pause").html("&#10073; &#10073;");
    		return false;
		});
		/* ]]> */
		<?php endif; ?>
		</script>
	<?php 
	
	$html .= ob_get_contents();

	ob_end_clean();

	return $html;
}
/**
 * clf_base_spotlight_gallery function.
 * 
 * @access public
 * @param mixed $atts
 * @return void
 */
function clf_base_spotlight_gallery($atts) {
	global $clf_base_options,$clf_base_spotlight_id;
	
	
	extract($atts);
	
	//jquery.cycle plugin option parameters.
    $jquery_cycle['fx'] = ($effect ? $effect : 'scrollHorz');
    $jquery_cycle['speed'] = (is_numeric($speed)) ? intval($speed) : '200';
    $jquery_cycle['pager'] = "#pager-".$clf_base_spotlight_id;
	$jquery_cycle['timeout'] = (is_numeric($timeout)) ? intval($timeout)*1000 : '6000';
	
	$html = '<div class="clf-base-spotlight clf-base-gallery-spotlight" id="clf-base-spotlight-'. $clf_base_spotlight_id.'">';
	
	$maxheight = 300;
	
	// Query for Posts in the category
	$spotlight_query = new WP_Query($query);
	
	// Abstracted the Loop Away in clf_base_spolight_wploop();
	$html .= clf_base_spotight_wploop($spotlight_query,$atts);
	$count = $spotlight_query->post_count;
	//Reset Query
	wp_reset_query();
 	ob_start(); // Start Output Buffer to contain spotlight code.
 	if($count > 1):
	?>
	<div class="controls">
		<a href="#next" id="play-pause-slides-<?php echo $clf_base_spotlight_id; ?>" class=" pause"><span>&#10073; &#10073;</span></a> 
		<a href="#previous-slide" id="previous-slide-<?php echo $clf_base_spotlight_id; ?>" class="previous-slide"><span>&laquo;</span></a> 
		<span id="slider-info-<?php echo $clf_base_spotlight_id; ?>" class="slider-info">1 / <?php echo $count; ?></span> 
		<a href="#next-slide" id="next-slide-<?php echo $clf_base_spotlight_id; ?>" class="next-slide"><span>&raquo;</span></a>
	</div>
	<div class="spotlight-pager" id="pager-<?php echo $clf_base_spotlight_id; ?>"></div>
	<?php endif;?> 
	</div>
		
		<script  type='text/javascript'>
		/* <![CDATA[ */
		/* Javascript Adaptive Setting of Width and Height */
		<?php if($width==null): ?>
			var width = jQuery("#clf-base-spotlight-<?php echo $clf_base_spotlight_id; ?>").width();
		<?php else: ?>	
			var width = <?php echo $width; ?>;
		<?php endif; ?>
		
		<?php $height = ($height!=null) ? $height : $maxheight; ?>
		
		/* Javascript to set appearance of slider controls	*/
		jQuery("#clf-base-spotlight-<?php echo $clf_base_spotlight_id; ?>").css({
			'width': width+'px',
			'height':'<?php echo $height+28; ?>px'
		});
		jQuery("#clf-base-spotlight-<?php echo $clf_base_spotlight_id; ?> div.slide, #clf-base-spotlight-<?php echo $clf_base_spotlight_id; ?> div.story-slide").css({
			'width':width+'px',
			'height':'<?php echo $height; ?>px'
		});
		jQuery("#clf-base-spotlight-<?php echo $clf_base_spotlight_id; ?>").find('.overlay-below').css({'width':width+'px'});
		jQuery("#clf-base-spotlight-<?php echo $clf_base_spotlight_id; ?>").find('.overlay').css({'width':width-20+'px'});
		jQuery("#clf-base-spotlight-<?php echo $clf_base_spotlight_id; ?> .spotlight-pager").css({"position":'absolute','top':'<?php echo $height; ?>px','right':0});
		<?php if($count > 1): ?>
		jQuery("#previous-slide-<?php echo $clf_base_spotlight_id; ?>, #next-slide-<?php echo $clf_base_spotlight_id; ?>").css({'top':'<?php echo ($height-11)/2; ?>px'});
		
		jQuery("#clf-base-spotlight-<?php echo $clf_base_spotlight_id; ?>").cycle({
			<?php 
			foreach($jquery_cycle as $attrkey => $attrvalue) {
				echo $attrkey.": '".$attrvalue."',";
			}
			?>
		    height: 'auto',
		    slideExpr:  "div.slide",
		    next: 	"#next-slide-<?php echo $clf_base_spotlight_id; ?>",
		    prev: 	"#previous-slide-<?php echo $clf_base_spotlight_id; ?>",
		    after:  function(currSlideElement, nextSlideElement, options, forwardFlag) 
        	{	
            	jQuery('#slider-info-<?php echo $clf_base_spotlight_id; ?>').text((options.currSlide + 1).toString() + ' / ' +options.slideCount);
        	}
		});
		
		/* Play & Pause Buttons */
		jQuery('#play-pause-slides-<?php echo $clf_base_spotlight_id; ?>').toggle(
		function() { 
			jQuery('#clf-base-spotlight-<?php echo $clf_base_spotlight_id; ?>').cycle('pause'); 
			jQuery(this).attr("class","play").html("&#9654;");
			return false;
		},
		function() { 
			jQuery("#clf-base-spotlight-<?php echo $clf_base_spotlight_id; ?>").cycle('resume');
    		jQuery(this).attr("class","pause").html("&#10073; &#10073;");
    		return false;
		});
		<?php endif; ?>
		/* ]]> */
		</script>
	<?php 
	
	$html .= ob_get_contents();

	ob_end_clean();
	return $html;
}
/**
 * clf_base_spotlight_blank function.
 * 
 * @access public
 * @param mixed $atts
 * @return void
 */
function clf_base_spotlight_blank($atts) {
	global $clf_base_options,$clf_base_spotlight_id;
	
	extract($atts);
	
	//jquery.cycle plugin option parameters.
	$jquery_cycle['fx'] = ($effect ? $effect : 'fade');
	$jquery_cycle['timeout'] = (is_numeric($timeout)) ? intval($timeout)*1000 : '6000';
	$jquery_cycle['speed'] = (is_numeric($speed)) ? intval($speed) : '200';
	
	
	$html .= '<div class="clf-base-spotlight clf-base-blank-spotlight" id="clf-base-spotlight-'. $clf_base_spotlight_id.'">';
	
	
	$maxheight = 300;
	
	// Query for Posts in the category
	$spotlight_query = new WP_Query($query);
	
	// Abstracted the Loop Away in clf_base_spolight_wploop();
	$html.=	clf_base_spotight_wploop($spotlight_query,$atts);
	$count = $spotlight_query->post_count;
	//Reset Query
	wp_reset_query();
 	ob_start(); // Start Output Buffer to contain spotlight code.
 	
	?>
	
	</div>
		
		<script  type='text/javascript'>
		/* <![CDATA[ */
		/* Javascript Adaptive Setting of Width and Height */
		<?php if($width==null): ?>
			var width = jQuery("#clf-base-spotlight-<?php echo $clf_base_spotlight_id; ?>").width();
		<?php else: ?>	
			var width = <?php echo $width; ?>;
		<?php endif; ?>
		
		<?php $height = ($height!=null) ? $height : $maxheight; ?>
		/* Javascript to set appearance of slider controls */
		jQuery("#clf-base-spotlight-<?php echo $clf_base_spotlight_id; ?>, #clf-base-spotlight-<?php echo $clf_base_spotlight_id; ?> div.slide, #clf-base-spotlight-<?php echo $clf_base_spotlight_id; ?> div.story-slide").css({
			'width': width+'px',
			'height':'<?php echo $height; ?>px'
		});
		<?php if($count > 1 ): ?>
		jQuery("#clf-base-spotlight-<?php echo $clf_base_spotlight_id; ?>").cycle({
			<?php 
			foreach($jquery_cycle as $attrkey => $attrvalue) {
				echo $attrkey.": '".$attrvalue."',";
			}
			?>
		    height: 'auto',
		    slideExpr:  "div.slide"
		});
		<?php endif; ?>
		/* ]]> */
		</script>
	<?php 
	$html .= ob_get_contents();

	ob_end_clean();
	return $html;
}

/**
 * clf_base_spotlight_transparent function.
 * 
 * @access public
 * @param mixed $atts
 * @return void
 */
function clf_base_spotlight_transparent($atts) {
	global $clf_base_options,$clf_base_spotlight_id;
	
	extract($atts);
	
	//jquery.cycle plugin option parameters.
    $jquery_cycle['fx'] = ($effect ? $effect : 'scrollHorz');
    $jquery_cycle['speed'] = (is_numeric($speed)) ? intval($speed) : '200';
    $jquery_cycle['pager'] = "#pager-".$clf_base_spotlight_id;
	$jquery_cycle['timeout'] = (is_numeric($timeout)) ? intval($timeout)*1000 : '6000';
	

	$html = '<div class="clf-base-spotlight clf-base-transparent-spotlight" id="clf-base-spotlight-'. $clf_base_spotlight_id.'">';
	
	$maxheight = 300;
	
	// Query for Posts in the category
	$spotlight_query = new WP_Query($query);
	
	// Abstracted the Loop Away in clf_base_spolight_wploop();
	$html .= clf_base_spotight_wploop($spotlight_query,$atts);
	$count = $spotlight_query->post_count;
	//Reset Query
	wp_reset_query();
 	ob_start(); // Start Output Buffer to contain spotlight code.
 	if($count > 1):
	?>
	<div class="controls">
		<a href="#previous-slide" id="previous-slide-<?php echo $clf_base_spotlight_id; ?>" class="previous-slide"><span>&lt;</span></a> 
		<a href="#next-slide" id="next-slide-<?php echo $clf_base_spotlight_id; ?>" class="next-slide"><span>&gt;</span></a>
	</div>
	<?php endif; ?>
	</div>
		
		<script  type='text/javascript'>
		/* <![CDATA[ */
		/* Javascript Adaptive Setting of Width and Height */
		<?php if($width==null): ?>
			var width = jQuery("#clf-base-spotlight-<?php echo $clf_base_spotlight_id; ?>").width();
		<?php else: ?>	
			var width = <?php echo $width; ?>;
		<?php endif; ?>
		
		<?php $height = ($height!=null) ? $height : $maxheight; ?>
		
		/* Javascript to set appearance of slider controls	*/
		jQuery("#clf-base-spotlight-<?php echo $clf_base_spotlight_id; ?>").css({
			'width': width+'px',
			'height':'<?php echo $height; ?>px'
		});
		jQuery("#clf-base-spotlight-<?php echo $clf_base_spotlight_id; ?> div.slide, #clf-base-spotlight-<?php echo $clf_base_spotlight_id; ?> div.story-slide").css({
			'width':width+'px',
			'height':'<?php echo $height; ?>px'
		});
	
		<?php if($count > 1): ?>
		
		jQuery("#clf-base-spotlight-<?php echo $clf_base_spotlight_id; ?>").cycle({
			<?php 
			foreach($jquery_cycle as $attrkey => $attrvalue) {
				echo $attrkey.": '".$attrvalue."',";
			}
			?>
		    height: 'auto',
		    slideExpr:  "div.slide",
		    next: 	"#next-slide-<?php echo $clf_base_spotlight_id; ?>",
		    prev: 	"#previous-slide-<?php echo $clf_base_spotlight_id; ?>"
		   
		});
		<?php endif; ?>
		/* ]]> */
		</script>
	<?php 
	
	$html .= ob_get_contents();

	ob_end_clean();
	return $html;
}

/**
 * clf_base_spotlight_multi function.
 * 
 * @access public
 * @param mixed $atts
 * @return void
 */
function clf_base_spotlight_multi($atts) {
	global $clf_base_options,$clf_base_spotlight_id, $post;
	
	extract($atts);
	//jquery.cycle plugin option parameters.
    $jquery_cycle['fx'] = ($effect ? $effect : 'fade');
    $jquery_cycle['speed'] = (is_numeric($speed)) ? intval($speed) : '200';
    $jquery_cycle['pager'] = "#pager-".$clf_base_spotlight_id;
	$jquery_cycle['timeout'] = (is_numeric($timeout)) ? intval($timeout)*1000 : '6000';
	
	
	 // determine what width type are we using 
	$single_column = false;
	
	if(!is_front_page()  ):
		$clf_base_layout_a = get_post_meta($post->ID, 'clf_base_layout_value');
		
		if($clf_base_layout_a[0] == 'l1-column' ):
			$single_column = true;
		elseif( $clf_base_layout_a[0] == 'default' && $clf_base_options['layout'] == 'l1-column'):
			$single_column = true;
		endif;
	endif;
	
	
	if(($atts['frontpage_option'] == '2' && is_front_page()) || $single_column) : // Full width frontpage option? 
		$atts['width'] = 560;
		
		if(empty($atts['height']))
			$atts['height'] = ($clf_base_options['frontpage']['spotlight']['height'] ? $clf_base_options['frontpage']['spotlight']['height'] : 200);
		
		$thumb_width = "113";
		$thumb_height = "84";
		
		$option = "full-width";
		
	else: // ... or the 560px width frontpage option?
		$atts['width'] = 350;
		
		if(empty($atts['height']))
			$atts['height'] = ($clf_base_options['frontpage']['spotlight']['height'] ? $clf_base_options['frontpage']['spotlight']['height'] : 200);
		
		$thumb_width = "107";
		$thumb_height = "80";
		
		$option = "small-width";

	endif;
	
	extract($atts);
	
	$html = '<div class="clf-base-spotlight clf-base-multi-spotlight" id="clf-base-spotlight-'. $clf_base_spotlight_id.'">';
	
	$maxheight = 300;
	
	// Query for Posts in the category
	$spotlight_query = new WP_Query($query);
	
	// Abstracted the Loop Away in clf_base_spolight_wploop();
	$html .= clf_base_spotight_wploop($spotlight_query,$atts);
	$count = $spotlight_query->post_count;
	//Reset Query
	wp_reset_query();
 	ob_start(); // Start Output Buffer to contain spotlight code.
 	// (int) $multiplyer =  /20;
 	$css_height = ($height-20);
	?>
	
	</div>
		<style type="text/css">
			#clf-base-spotlight-<?php echo $clf_base_spotlight_id; ?> .overlay{
				height: <?php echo $height-63; ?>px;
			}
		</style>
		<script  type='text/javascript'>
		/* <![CDATA[ */
		/* Javascript Adaptive Setting of Width and Height */
		<?php if($width==null): ?>
			var width = jQuery("#clf-base-spotlight-<?php echo $clf_base_spotlight_id; ?>").width();
		<?php else: 
		
			if($option == "full-width"): ?> /* Full width frontpage option? */
				var width = 944;
			<?php else: ?> /* ... or the 560px width frontpage option? */
				var width = 555;
			<?php endif; ?>	
			
		<?php endif; ?>
		
		<?php $height = ($height!=null) ? $height : $maxheight; ?>
		
		/* Javascript to set appearance of slider controls	*/
		jQuery("#clf-base-spotlight-<?php echo $clf_base_spotlight_id; ?>").css({'width': width+'px'}).find('div.slide').css({'width': width+'px'});
		
		
		<?php if($count > 1): ?>
		jQuery("#clf-base-spotlight-<?php echo $clf_base_spotlight_id; ?>").after('<ul id="clf-base-pager-<?php echo $clf_base_spotlight_id; ?>" class="image-pager">').cycle({ 
			<?php 
			foreach($jquery_cycle as $attrkey => $attrvalue) {
				echo $attrkey.": '".$attrvalue."',";
			}
			?>
    		pager:  '#clf-base-pager-<?php echo $clf_base_spotlight_id; ?>', 
     		pagerEvent: 'mouseover', 
    		fastOnEvent: true,
    		/* callback fn that creates a thumbnail to use as pager anchor */
   		 pagerAnchorBuilder: function(idx, slide) { 
	    	/* get the url */
			var src = jQuery(slide).children('a').children('img').attr('src');
			var url = jQuery(slide).find('.slide-image-link').attr('href');
			
	    	var w = gup(src,"w");
	    	var h = gup(src,"h");
	    	if(src) {
	    		 return '<li class="thumb-shell"><a href="'+url+'" onclick=" window.location = \''+url+'\';"><img src="' + src.replace("&w="+w,"&w=<?php echo $thumb_width; ?>").replace("&h="+h,"&h=<?php echo $thumb_height; ?>")+ '" width="<?php echo $thumb_width; ?>" height="<?php echo $thumb_height; ?>"  /></a></li>'; 
	    	
	    	}else{
	    		
	    		return "";
	    	}
       
   		 } 
		});
		<?php endif; ?>
		/* get url parameters */
		function gup(url, name )
		{
		  name = name.replace(/[\[]/,"\\\[").replace(/[\]]/,"\\\]");
		  var regexS = "[\\?&]"+name+"=([^&#]*)";
		  var regex = new RegExp( regexS );
		  var results = regex.exec(url );
		  if( results == null )
		    return "";
		  else
		    return results[1];
		}
		/* ]]> */
		</script>
		
	<?php 
	
	$html .= ob_get_contents();

	ob_end_clean();
	return $html;
}

/**
 * clf_base_spotight_wploop function.
 * 
 * @access public
 * @param mixed $spotlight_query
 * @param mixed $thumbstyle
 * @param mixed $read_more_check
 * @param mixed $read_more_text
 * @return void
 */
function clf_base_spotight_wploop($spotlight_query,$atts) {
	global  $clf_base_options;
	
	extract($atts);
	
	// forces the images to be a particular width
	$width = ( isset( $clf_base_options['frontpage']['spotlight']['force_width'] ) && is_numeric( $clf_base_options['frontpage']['spotlight']['force_width'] ) ? $clf_base_options['frontpage']['spotlight']['force_width'] : $width );
	
	//The Loop
	$count = 0;
	
	if ( $spotlight_query->have_posts() ) : 
	$read_more_text = (!empty($read_more_text)? $read_more_text: "Read More");
	while ( $spotlight_query->have_posts() ) : 
		$spotlight_query->the_post();
		$count++;	
		$html .='<div class="slide">';
			
			$image = clf_base_get_the_image(get_the_ID(),$width,$height);
	
			if($image):
				if($remove_link_to):
					$html .= '
		        	'.$image.'
		        	<div class="overlay-below"></div>
		        	<div class="overlay">
		        		<h2 class="entry-title">'.get_the_title().'</h2>
		        		<div class="excert">
		        			'. get_the_excerpt(). '
		        		</div>';
		        		if($read_more_check)
		        		$html .= '<span class="read-more-shell"><a class="read-more-button" href="'. get_permalink().'" title="'.the_title_attribute(array( 'echo' => false )).'">'.$read_more_text.'</a></span>';
		        	$html .= '</div>';
				else:
					$html .= '
		        	<a href="'.get_permalink().'" title="'.the_title_attribute(array( 'echo' => false )).'" class="slide-image-link"> '.$image.'</a>
		        	<div class="overlay-below"></div>
		        	<div class="overlay">
		        		<h2 class="entry-title"><a href="'. get_permalink().'" title="'.the_title_attribute(array( 'echo' => false )).'">'.get_the_title().'</a></h2>
		        		<div class="excert">
		        			'. get_the_excerpt(). '
		        		</div>';
		        		if($read_more_check)
		        		$html .= '<span class="read-more-shell"><a class="read-more-button" href="'. get_permalink().'" title="'.the_title_attribute(array( 'echo' => false )).'">'.$read_more_text.'</a></span>';
		        	$html .= '</div>';
	        	endif;
	        	
        	else: 
	        	$html .= ' 
	        	<div class="story-slide">
	        		<div class="story">
	        		<h2 class="entry-title"><a  href="'. get_permalink().'" title="'.the_title_attribute(array( 'echo' => false )).'">'.get_the_title().'</a></h2>
	                
	        		<div class="story-excert">
	        			'.get_the_excerpt().'
	        		</div>';
	              	if($read_more_check)
	        		$html .= '<a class="read-more-button" href="'. get_permalink().'" title="'.the_title_attribute(array( 'echo' => false )).'">'.$read_more_text.'</a>';
	        		
	        		
	        	$html .= '</div></div>';
        	endif;
		$html .='</div>';
	
		
		unset($image); // reset the image variable
	endwhile;
	return $html;
	endif;
	
	return "";
}

function clf_base_get_the_image_src($post_id=NULL) {
	global $id;
	$post_id = ( NULL === $post_id ) ? $id : $post_id;
	
	$thumb_id = get_post_thumbnail_id( $post_id );
	if($thumb_id):
		$img_url = wp_get_attachment_url($thumb_id);
	else:
	// this still needs to be tested 
		$defaults = array(
					'custom_key' => array("Feature_Image"),
					'post_id' => $post_id, // Build functionality in later
					'attachment' => true,
					'default_size' => 'full',
					'default_image' => false,
					'order_of_image' => 1,
					'link_to_post' => true,
					'image_class' => false,
					'image_scan' => false,
					'width' => false,
					'height' => false,
					'format' => 'array',
					'echo' => false,
				);
			$image_array = get_the_image($defaults); 
	
		$img_url = $image_array['url'];	
		
	endif;
	
	return $img_url;
	
}

function clf_base_get_the_image($post_id=NULL, $width=100, $height=100,$quality=80,$sharpen=0,$align='c',$filters=null){
	global $id,$blog_id;
	$post_id = ( NULL === $post_id ) ? $id : $post_id;
	
	$src = clf_base_get_the_image_src($post_id);
	
	if (isset($blog_id) && $blog_id > 0) {
	$imageParts = explode('/files/', $src);
	if (isset($imageParts[1])) {
		$src = '/blogs.dir/' . $blog_id . '/files/' . $imageParts[1];
		}
	}
	if($filters)
		$filters = "&f=".$filters;
		
		if($src):
				$url = get_bloginfo('wpurl')."/wp-content/themes/clf-base/library/images/timthumb.php?src=".urlencode($src)."&w=".$width."&h=".$height."&q=".$quality."&s=".$sharpen."&a=".$align."&bid=".$blog_id.$filters;
		return '<img src="'.esc_url($url).'" alt="" class="" title="" height="'.$height.'" width="'.$width.'" />';
		
		else:
			return "";
		endif;
}






