<?php
/**
 * Navigation
 *
 */
 
global $clf_base_load_backend;
if($clf_base_load_backend)
	require_once("panel.php");

add_action('init','clf_base_navigation_init');

/**
 * clf_base_navigation_init function.
 * 
 * @access public
 * @return void
 */
function clf_base_navigation_init() {
	global $clf_base_options;
	
	// deregister 
	
	if(!is_admin()):
		wp_enqueue_script('clf-base-spotlight', get_bloginfo('stylesheet_directory').'/library/frontpage/spotlight/js/spotlight.js',array('jquery'));
	endif;
	
	/* use a different page navigation */
	remove_action( 'hybrid_after_header', 'hybrid_page_nav' );
	if($clf_base_options['navigation']['top']['enable'])
		add_action( 'hybrid_after_header', 'clf_base_page_nav' );
	
	remove_action( 'hybrid_before_content', 'hybrid_breadcrumb' );
	if( $clf_base_options['navigation']['breadcrumbs']['enable'] )
		add_action( 'hybrid_after_header','hybrid_breadcrumb',14);	
		
	add_filter('breadcrumb_trail_args','clf_base_navigation_breadcrumb_trail_args',10);
	
	// add the javascript 
	if(!is_admin() && $clf_base_options['navigation']['dropdown']['type'] != 'fullwidth-dropdown' && $clf_base_options['navigation']['dropdown']['superfish']['enable']):	
		wp_enqueue_script('clf-base-navigation', get_bloginfo('stylesheet_directory').'/library/navigation/js/superfish.js',array('jquery'));
	endif;
	
	register_nav_menu( 'header-menu', __( 'Header Menu' ) );

}    

/**
 * clf_base_page_nav function.
 * 
 * @access public
 * @return void
 */	
function clf_base_page_nav() {
	global $clf_base_options,$post; 
	
	
	echo '<div id="navigation">' . "\n\t\t\t";
	
	$depth = 1;
	if($clf_base_options['navigation']['dropdown']['enable']) 
			$depth = (is_numeric($clf_base_options['navigation']['dropdown']['depth'])) ? $clf_base_options['navigation']['dropdown']['depth'] : 3;
		
	
	if ( has_nav_menu( 'header-menu' ) ):
		$args = array( 
		'theme_location'  => 'header-menu', 
		'container_class' => ' page-nav '.$clf_base_options['navigation']['style'].' '.$clf_base_options['navigation']['dropdown']['type'] ,
		'echo'			  => 0 , 
		
		);
		if(isset($clf_base_options['navigation']['dropdown']['page-caption']['enable']))
			$args['walker'] =  new Caption_Walker_Menu();
		$nav = wp_nav_menu( $args );
	else:
		
		
		$show_on_front = get_option("show_on_front");
		$home_id = get_option("page_on_front");
		
		if($home_id && $show_on_front =="page") {
			$post_temp = $post;
			$home = get_page($page_id);
			$show_home  = $page->post_title;
			$post = $post_temp;
			
		} else {
			$show_home  = __('Home', 'hybrid');
		}
		
		$args = array(
			'show_home' => $show_home,
			'menu_class' => 'depth-'.$depth.' page-nav '.$clf_base_options['navigation']['style'].' '.$clf_base_options['navigation']['dropdown']['type'],
			'sort_column' => 'menu_order',
			'depth' => $depth,
			'echo' => 0,
		);
		
		if(isset($clf_base_options['navigation']['dropdown']['page-caption']['enable']))
			$args['walker'] =  new Caption_Walker_Page();
		
		$menu = wp_page_menu( $args );
		$nav = str_replace( array( "\r", "\n", "\t" ), '', $menu );

		
	endif;
	$nav = str_replace( '<div class="', '<div id="menu-top-menu" class="', $nav );
	$nav = str_replace( '<ul id="menu-top-menu" class="menu">', '<ul>', $nav );
	

	echo preg_replace( '/<ul>/', '<ul class="menu sf-menu ">', $nav, 1 );
	// echo $nav;
	echo "\n\t</div><!-- #navigation -->\n";
	
}

/**
 * clf_base_page_nav_filter function.
 * 
 * @access public
 * @param mixed $matches
 * @return void

function clf_base_page_nav_filter($matches) {
	return $matches[0];
}
*/

/**
 * clf_base_navigation_breadcrumb_trail_args function.
 * 
 * @access public
 * @param mixed $args
 * @return void
 */
function clf_base_navigation_breadcrumb_trail_args($args)
{
	global $clf_base_options;
	
	$args['before'] 	= $clf_base_options['navigation']['breadcrumbs']['before'];
	$args['after'] 		= $clf_base_options['navigation']['breadcrumbs']['after'];
	$args['separator'] 	= $clf_base_options['navigation']['breadcrumbs']['separator'];
	$args['show_home'] 	= $clf_base_options['navigation']['breadcrumbs']['show_home'];
	
	return $args;
}


class Caption_Walker_Menu extends Walker_Nav_Menu
{	
	var $inserted_captions = array();
	
	function start_el(&$output, $item, $depth, $args) {
		global $wp_query;
		$indent = ( $depth ) ? str_repeat( "\t", $depth ) : '';

		$class_names = $value = '';

		$classes = empty( $item->classes ) ? array() : (array) $item->classes;
		$classes[] = 'menu-item-' . $item->ID;

		$class_names = join( ' ', apply_filters( 'nav_menu_css_class', array_filter( $classes ), $item ) );
		$class_names = ' class="' . esc_attr( $class_names ) . '"';

		$id = apply_filters( 'nav_menu_item_id', 'menu-item-'. $item->ID, $item, $args );
		$id = strlen( $id ) ? ' id="' . esc_attr( $id ) . '"' : '';
		
		$caption = get_post_meta( $item->post_parent, 'page-caption', true) ? '<em class="page-caption">'.esc_html(get_post_meta( $item->post_parent, 'page-caption', true)).'</em>' : '';
		if($caption && !in_array($item->post_parent,$this->inserted_captions) ):
			$this->inserted_captions[] = $item->post_parent;
			
			$output .=	"<li class='page-caption-shell'>".$caption."</li>";
		endif;
		$output .= $indent . '<li' . $id . $value . $class_names .'>';

		$attributes  = ! empty( $item->attr_title ) ? ' title="'  . esc_attr( $item->attr_title ) .'"' : '';
		$attributes .= ! empty( $item->target )     ? ' target="' . esc_attr( $item->target     ) .'"' : '';
		$attributes .= ! empty( $item->xfn )        ? ' rel="'    . esc_attr( $item->xfn        ) .'"' : '';
		$attributes .= ! empty( $item->url )        ? ' href="'   . esc_attr( $item->url        ) .'"' : '';

		$item_output = $args->before;
		$item_output .= '<a'. $attributes .'>';
		$item_output .= $args->link_before . apply_filters( 'the_title', $item->title, $item->ID ) . $args->link_after;
		$item_output .= '</a>';
		$item_output .= $args->after;

		$output .= apply_filters( 'walker_nav_menu_start_el', $item_output, $item, $depth, $args );
	}	
}
	
class Caption_Walker_Page extends Walker_Page
	{
		  
	var $inserted_captions = array();
	/**
	 * @see Walker::start_el()
	 * @since 2.1.0
	 *
	 * @param string $output Passed by reference. Used to append additional content.
	 * @param object $page Page data object.
	 * @param int $depth Depth of page. Used for padding.
	 * @param int $current_page Page ID.
	 * @param array $args
	 */
	function start_el(&$output, $page, $depth, $args, $current_page) {
		if ( $depth )
			$indent = str_repeat("\t", $depth);
		else
			$indent = '';

		extract($args, EXTR_SKIP);
		$css_class = array('page_item', 'page-item-'.$page->ID);
		if ( !empty($current_page) ) {
			$_current_page = get_page( $current_page );
			if ( isset($_current_page->ancestors) && in_array($page->ID, (array) $_current_page->ancestors) )
				$css_class[] = 'current_page_ancestor';
			if ( $page->ID == $current_page )
				$css_class[] = 'current_page_item';
			elseif ( $_current_page && $page->ID == $_current_page->post_parent )
				$css_class[] = 'current_page_parent';
		} elseif ( $page->ID == get_option('page_for_posts') ) {
			$css_class[] = 'current_page_parent';
		}

		$css_class = implode(' ', apply_filters('page_css_class', $css_class, $page));
		$caption = get_post_meta( $page->post_parent, 'page-caption', true) ? '<em class="page-caption">'.esc_html(get_post_meta( $page->post_parent, 'page-caption', true)).'</em>' : '';
		
		if($caption && !in_array($page->post_parent,$this->inserted_captions) ):
			$this->inserted_captions[] = $page->post_parent;
			
			$output .=	"<li class='page-caption-shell'>".$caption."</li>";
		endif;
		
		$output .= $indent . '<li class="' . $css_class . '"><a href="' . get_page_link($page->ID) . '" title="' . esc_attr( wp_strip_all_tags( apply_filters( 'the_title', $page->post_title, $page->ID ) ) ) . '">' . $link_before . apply_filters( 'the_title', $page->post_title, $page->ID ) . $link_after . '</a>';

		if ( !empty($show_date) ) {
			if ( 'modified' == $show_date )
				$time = $page->post_modified;
			else
				$time = $page->post_date;

			$output .= " " . mysql2date($date_format, $time);
		}
	}

	}