<?php 

/** 
 * Shortcodes that are used by the byline 
 */
 
 
// [author],[author-link], [permalink], [date], [time], [comments_link], [comments-number], [post-categories],[post-tags], [post-revisions],[last-updated]
// add shortcodes

add_shortcode( 'author', 'clf_base_author_shortcode' );
add_shortcode( 'posts-author-link', 'clf_base_author_posts_link_shortcode' );
add_shortcode( 'modified-author','clf_base_modified_author_shortcode' );
add_shortcode( 'permalink', 'clf_base_permalink_shortcode' );

add_shortcode( 'date', 'clf_base_date_shortcode' );
add_shortcode( 'time', 'clf_base_time_shortcode' );
add_shortcode( 'modified_date', 'clf_base_modified_date_shortcode' );
add_shortcode( 'modified_time', 'clf_base_modified_time_shortcode' );


add_shortcode( 'the_post_thumbnail', 'clf_base_the_post_thumbnail_shortcode');
add_shortcode( 'the_post_thumbnail_src', 'clf_base_the_post_thumbnail_src_shortcode');

add_shortcode('comments', 'clf_base_comments_shortcode');
add_shortcode('comment-link', 'clf_base_comments_link_shortcode');
add_shortcode('categories', 'clf_base_post_categories_shortcode');
add_shortcode('tags', 'clf_base_post_tags_shortcode');
add_shortcode('revisions', 'clf_base_post_revisions_shortcode');
add_shortcode('last-updated', 'clf_base_last_updated_shortcode');

add_shortcode( 'the_content', 'clf_base_the_content_shortcode');
add_shortcode( 'the_excerpt', 'clf_base_the_excerpt_shortcode');

add_shortcode( 'child-pages', 'clf_base_childpages_shortcode');
add_shortcode( 'top','clf_base_top_shortcode');
add_shortcode( 'box','clf_base_box_shortcode');

/**
 * clf_base_author_shortcode function.
 * 
 * Displays the post/page author
 * @access public
 * @return void
 */
function clf_base_author_shortcode()
{
	return get_the_author();
}

/**
 * clf_base_the_content_shortcode function.
 * 
 * Displays the post content
 * @access public
 * @return void
 */
function clf_base_the_content_shortcode()
{
	$content = get_the_content();
	$content = apply_filters('the_content', $content);
	$content = str_replace(']]>', ']]&gt;', $content);

	return $content;
}

/**
 * clf_base_the_excerpt_shortcode function.
 * 
 * Displays the excerpt
 * @access public
 * @return void
 */
function clf_base_the_excerpt_shortcode()
{
	return get_the_excerpt();
}

/**
 * clf_base_author_posts_link_shortcode function.
 * 
 * Displays the link the authors posts archive page
 * with the authors nickname as the link text
 * @access public
 * @return void
 */
function clf_base_author_posts_link_shortcode()
{
	global $authordata;	
	return sprintf(
		'<a href="%1$s" title="%2$s">%3$s</a>',
		get_author_posts_url( $authordata->ID, $authordata->user_nicename ),
		sprintf( __( 'Posts by %s' ), attribute_escape( get_the_author() ) ),
		get_the_author()
	);
	
}
/**
 * clf_base_modified_author_shortcode function.
 * 
 * Displays the last person who changed the post/page
 * @access public
 * @return void
 */
function clf_base_modified_author_shortcode()
{
	return get_the_modified_author();
}

/**
 * clf_base_permalink_shortcode function.
 * 
 * Displays the permalink if a particular post/page
 * 
 * @access public
 * @param mixed $attr
 * @return void
 */
function clf_base_permalink_shortcode($attr)
{	
	global $post;
	
	if( 'feed_item' == $post->type )
		return $post->guid;
		
	$id = ( isset( $attr['id'] )? $attr['id']: null );
	return get_permalink( $id );
}

/**
 * clf_base_date_shortcode function.
 * 
 * Displays the publish date of post/page as defined in the general settings
 * publish time only appear once in the page that happen on the same date
 * @access public
 * @param mixed $attr
 * @return void
 */
function clf_base_date_shortcode($attr)
{	
	$format = ( isset($attr['format']) ? $attr['format'] : get_option('date_format'));
	return get_the_time( $format );
}

/**
 * clf_base_time_shortcode function.
 *
 * Displays the publish time of post/page as defined in the general settings
 * 
 * @access public
 * @param mixed $attr
 * @return void
 */
function clf_base_time_shortcode($attr)
{
	$format = ( isset($attr['format']) ? $attr['format'] : '');
	return get_the_time( $format );
}

/**
 * clf_base_modified_date_shortcode function.
 * 
 * Displays the modefied date of post/page as 
 * @access public
 * @param mixed $attr
 * @return void
 */
function clf_base_modified_date_shortcode( $attr ) {
	$format = ( isset($attr['format']) ? $attr['format'] : get_option('date_format'));
	return get_the_modified_date( $format );
}

/**
 * clf_base_modified_time_shortcode function.
 * 
 * Displays the modefied time of post/page as defined in the general settings
 * @access public
 * @param mixed $attr
 * @return void
 */
function clf_base_modified_time_shortcode( $attr ) {
	$format = ( isset($attr['format']) ? $attr['format'] : '');
	return get_the_modified_time( $format );
}
/**
 * clf_base_the_post_thumbnail_shortcode function.
 * size options - thumbnail,medium,large,full, page-header, single-post-slide, single-post-slide-half, single-post-wide-slide
 * [the_post_thumbnail size=thumbnail]
 * [the_post_thumbnail size=medium]
 * [the_post_thumbnail size= large]
 * [the_post_thumbnail size=full]
 * [the_post_thumbnail size=page-header]
 * [the_post_thumbnail size=single-post-slide]
 * [the_post_thumbnail size=single-post-slide-half]
 * [the_post_thumbnail size=single-post-wide-slide]
 * 
 * @access public
 * @param mixed $attr
 * @return void
 */
function clf_base_the_post_thumbnail_shortcode( $attr )
{
	extract(shortcode_atts(array(
		'size' => 'post-thumbnail',
		'width' =>null,
		'height'=>null,
	), $attr));
	
	
	
	if( $width && $height ):
		$size = array($width,$height);
	endif;
	return get_the_post_thumbnail(NULL,$size, $attr);
}

/**
 * clf_base_the_post_thumbnail_src_shortcode function.
 * size options - thumbnail,medium,large,full, page-header, single-post-slide, single-post-slide-half, single-post-wide-slide
 * timthumb = 1 gives you back the url of the image passed though the timthumb image processor
 * width and height, sizes in pixels - used by both timbthumb and wp_get_atacgemnet_img_src function
 * [the_post_thumbnail_src size=thumbnail]
 * [the_post_thumbnail_src size=medium]
 * [the_post_thumbnail_src size= large]
 * [the_post_thumbnail_src size=full]
 * [the_post_thumbnail_src size=page-header]
 * [the_post_thumbnail_src size=single-post-slide]
 * [the_post_thumbnail_src size=single-post-slide-half]
 * [the_post_thumbnail_src size=single-post-wide-slide]
 * @access public
 * @param mixed $attr
 * @return void
 */
function clf_base_the_post_thumbnail_src_shortcode( $attr ) {
	
	global $blog_id,$post;
	$default_blog_id = $blog_id;
	extract(shortcode_atts(array(
		'size' 		=> 'post-thumbnail',
		'width' 	=>null,
		'height'	=>null,
		'timthumb' 	=>null,
		'blog_id'  	=>$blog_id,
		'default'	=> null,
		'end'		=> '',
		'network' 	=> true
	), $attr));
	
	if( $width && $height ):
		$size = array($width,$height);
		$end =  "&w=".$width."&h=".$height.$end;
	endif;
	
	if($post->type != 'feed_item'):
		$attachment_id = get_post_thumbnail_id(NULL); // gives you the current id
		
		$image = wp_get_attachment_image_src( $attachment_id, $size, false );
		if(isset($image[0])):
			if( $timthumb ):
				$src = $image[0];
				if (isset($blog_id) && $blog_id > 0) {
				$imageParts = explode('/files/', $image[0]);
				if (isset($imageParts[1])) {
					$src = '/blogs.dir/' . $blog_id . '/files/' . $imageParts[1];
					}
				}
				$blog_id = $default_blog_id;
				$src = get_bloginfo('wpurl')."/wp-content/themes/clf-base/library/images/timthumb.php?bid=".$default_blog_id."&src=".urlencode($src).$end;
			endif;
			
			$blog_id = $default_blog_id;
			$src = $image[0];
		else:
			if(isset($default)):
				$src = $default;
			else:
				$src = "No Images";
			endif;
		endif;
		$blog_id = $default_blog_id;
		return $src;

	else: 
		// the conten is comming from a feed
		
		if($enclosure = $post->post_content_filtered->get_enclosure()):
			if(isset($timthumb) && isset($blog_id)) {
				$src = $enclosure->link;
				
				$imageParts = explode('/files/', $src);
				if ( isset($imageParts[1]) ) {
					$src = '/blogs.dir/' . $blog_id . '/files/' . $imageParts[1];
					$src = get_bloginfo('wpurl')."/wp-content/themes/clf-base/library/images/timthumb.php?bid=".$blog_id."&src=".urlencode($src).$end;
				} elseif($blog_id = 1) {
					$src = get_bloginfo('wpurl')."/wp-content/themes/clf-base/library/images/timthumb.php?bid=".$blog_id."&src=".urlencode($src).$end;
				}

			} elseif( isset($timthumb) ) {
				$src = $enclosure->link;
				$src = get_bloginfo('wpurl')."/wp-content/themes/clf-base/library/images/timthumb.php&src=".urlencode(   ).$end;
			
			} elseif($size == 'post-thumbnail' || $size= 'thumbnail' ) {
				$src = $enclosure->thumbnails[0];
			
			} else{
				$src = $enclosure->link;
			}
		else:
			if(isset($default)):
				$src = $default;
			else:
				$src = "No Images";
			endif;
		endif;
		$blog_id = $default_blog_id;
		return $src;
	endif; 
}
/**
 * clf_base_comments_shortcode function.
 * 
 * @access public
 * @param mixed $atts
 * @return void
 */
function clf_base_comments_shortcode($atts)
{	
	extract(shortcode_atts(array(
		'no_comments' => false,
		'one_comment' => false,
		'numer_of_comments' =>false
	), $atts));
	ob_start(); ?>
	<a href="<?php echo get_comments_link(); ?>"><?php comments_number($no_comments,$one_comment,$numer_of_comments); ?></a>
	<?php 
	return ob_get_clean();
}
function clf_base_comments_link_shortcode()
{
	return get_comments_link();
}


function clf_base_post_categories_shortcode($attr)
{
	if ( isset( $attr['post_id'] ) )
		$attr['post_id'] = (int)$attr['post_id'];
	else
		$attr['post_id']  = false;
	$parents = ( in_array( $attr['parents'], array( 'multiple', 'single' ) ) ? $attr['parents'] : false );
	$separator = ( isset( $attr['separator'] ) ? $attr['separator']: ", ");
	
	return get_the_category_list( $separator, $parents, $attr['post_id'] );
}

function clf_base_post_tags_shortcode( $attr ) {
	$separator = ( isset( $attr['separator'] ) ? $attr['separator'] : ", ");
		
	$before = ( isset( $attr['before'] ) ? $attr['before'] : '');
	$after = ( isset( $attr['after'] ) ? $attr['after'] : '');
	
	return get_the_tag_list( $before, $separator, $after );
}

/**
 * clf_base_post_revisions_shortcode function.
 * 
 * Displays the current post revisions to the logged in user. 
 *
 * @access public
 * @return void
 */
function clf_base_post_revisions_shortcode()
{
	global $post;
	$args = array( 'parent' => true,  'type'=>'revision');
	return wp_list_post_revisions($post->ID, $args);

}
/**
 * clf_base_last_updated_shortcode function.
 * 
 * Displays the last updated on and the date and time of a post/page
 * @access public
 * @return void
 */
function clf_base_last_updated_shortcode($attr)
{
	$format = (isset($attr['format']) ? $attr['format']: "F j, Y @g:i a");
	return get_the_modified_time( $format );

}

function clf_base_childpages_shortcode($depth=0)
{
	global $post;
	
	$args = array(
    'depth'        => $depth,
    'date_format'  => get_option('date_format'),
    'child_of'     => $post->ID,
 	'title_li'     => __(''),
    'echo'         => false,
    'sort_column'  => 'menu_order, post_title'
    );
    $child_pages = wp_list_pages( $args );
    
    if($child_pages)
		return "<div class='nav'><ul class='child-pages'>".$child_pages."</ul></div>";
	else
		return "";
}

function clf_base_top_shortcode($attr=null,$text1=null)
{
	$text = ( $attr['text']? $attr['text']:"top" );
	$text = ( $text1? $text1:$text );
	return "<a href='#top' class='top'>{$text}</a>";
}


function clf_base_box_shortcode($attr=null,$text=null)
{
	$style = "";
	if($attr['style'])
		$style = "style='{$attr['style']}'";
	return "<div class='box' {$style} >{$text}</div>";
}


